# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'premisgui.ui'
#
# Created by: PyQt4 UI code generator 4.11.4
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    def _fromUtf8(s):
        return s

try:
    _encoding = QtGui.QApplication.UnicodeUTF8
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig, _encoding)
except AttributeError:
    def _translate(context, text, disambig):
        return QtGui.QApplication.translate(context, text, disambig)

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(877, 638)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.tabWidget = QtGui.QTabWidget(self.centralwidget)
        self.tabWidget.setGeometry(QtCore.QRect(0, 10, 411, 471))
        self.tabWidget.setObjectName(_fromUtf8("tabWidget"))
        self.scanningTab = QtGui.QWidget()
        self.scanningTab.setObjectName(_fromUtf8("scanningTab"))
        self.filmCaptureInterventionsListBox = QtGui.QListWidget(self.scanningTab)
        self.filmCaptureInterventionsListBox.setGeometry(QtCore.QRect(10, 50, 281, 171))
        self.filmCaptureInterventionsListBox.setAlternatingRowColors(False)
        self.filmCaptureInterventionsListBox.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        self.filmCaptureInterventionsListBox.setObjectName(_fromUtf8("filmCaptureInterventionsListBox"))
        item = QtGui.QListWidgetItem()
        self.filmCaptureInterventionsListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmCaptureInterventionsListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmCaptureInterventionsListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmCaptureInterventionsListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmCaptureInterventionsListBox.addItem(item)
        self.lineEdit = QtGui.QLineEdit(self.scanningTab)
        self.lineEdit.setGeometry(QtCore.QRect(10, 20, 161, 20))
        self.lineEdit.setObjectName(_fromUtf8("lineEdit"))
        self.filmPreparationListBox = QtGui.QListWidget(self.scanningTab)
        self.filmPreparationListBox.setGeometry(QtCore.QRect(10, 270, 281, 141))
        self.filmPreparationListBox.setAlternatingRowColors(False)
        self.filmPreparationListBox.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        self.filmPreparationListBox.setObjectName(_fromUtf8("filmPreparationListBox"))
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        item = QtGui.QListWidgetItem()
        self.filmPreparationListBox.addItem(item)
        self.lineEdit_2 = QtGui.QLineEdit(self.scanningTab)
        self.lineEdit_2.setGeometry(QtCore.QRect(10, 240, 141, 20))
        self.lineEdit_2.setObjectName(_fromUtf8("lineEdit_2"))
        self.tabWidget.addTab(self.scanningTab, _fromUtf8(""))
        self.tapeTab = QtGui.QWidget()
        self.tapeTab.setObjectName(_fromUtf8("tapeTab"))
        self.tapeDeckList = QtGui.QListWidget(self.tapeTab)
        self.tapeDeckList.setGeometry(QtCore.QRect(10, 110, 256, 192))
        self.tapeDeckList.setObjectName(_fromUtf8("tapeDeckList"))
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        item = QtGui.QListWidgetItem()
        self.tapeDeckList.addItem(item)
        self.tapeFormatComboBox = QtGui.QComboBox(self.tapeTab)
        self.tapeFormatComboBox.setGeometry(QtCore.QRect(10, 30, 191, 26))
        self.tapeFormatComboBox.setObjectName(_fromUtf8("tapeFormatComboBox"))
        self.tapeFormatComboBox.addItem(_fromUtf8(""))
        self.tapeFormatComboBox.addItem(_fromUtf8(""))
        self.tapeFormatComboBox.addItem(_fromUtf8(""))
        self.tapeFormatComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox = QtGui.QComboBox(self.tapeTab)
        self.tapeWorkstationComboBox.setGeometry(QtCore.QRect(10, 60, 191, 26))
        self.tapeWorkstationComboBox.setObjectName(_fromUtf8("tapeWorkstationComboBox"))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.tapeWorkstationComboBox.addItem(_fromUtf8(""))
        self.ffv1CheckBox = QtGui.QCheckBox(self.tapeTab)
        self.ffv1CheckBox.setGeometry(QtCore.QRect(40, 340, 231, 20))
        self.ffv1CheckBox.setObjectName(_fromUtf8("ffv1CheckBox"))
        self.tabWidget.addTab(self.tapeTab, _fromUtf8(""))
        self.rawAudioTab = QtGui.QWidget()
        self.rawAudioTab.setObjectName(_fromUtf8("rawAudioTab"))
        self.rawAudioInterventions = QtGui.QListWidget(self.rawAudioTab)
        self.rawAudioInterventions.setGeometry(QtCore.QRect(10, 0, 256, 251))
        self.rawAudioInterventions.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        self.rawAudioInterventions.setObjectName(_fromUtf8("rawAudioInterventions"))
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        item = QtGui.QListWidgetItem()
        self.rawAudioInterventions.addItem(item)
        self.tabWidget.addTab(self.rawAudioTab, _fromUtf8(""))
        self.gradeTab = QtGui.QWidget()
        self.gradeTab.setObjectName(_fromUtf8("gradeTab"))
        self.listWidget = QtGui.QListWidget(self.gradeTab)
        self.listWidget.setGeometry(QtCore.QRect(10, 10, 391, 341))
        self.listWidget.setSelectionMode(QtGui.QAbstractItemView.MultiSelection)
        self.listWidget.setObjectName(_fromUtf8("listWidget"))
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        item = QtGui.QListWidgetItem()
        self.listWidget.addItem(item)
        self.tabWidget.addTab(self.gradeTab, _fromUtf8(""))
        self.userComboBox = QtGui.QComboBox(self.centralwidget)
        self.userComboBox.setGeometry(QtCore.QRect(560, 20, 111, 22))
        self.userComboBox.setObjectName(_fromUtf8("userComboBox"))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.userComboBox.addItem(_fromUtf8(""))
        self.lineEdit_3 = QtGui.QLineEdit(self.centralwidget)
        self.lineEdit_3.setGeometry(QtCore.QRect(440, 20, 113, 20))
        self.lineEdit_3.setObjectName(_fromUtf8("lineEdit_3"))
        self.oeTextBox = QtGui.QPlainTextEdit(self.centralwidget)
        self.oeTextBox.setGeometry(QtCore.QRect(440, 80, 291, 41))
        self.oeTextBox.setInputMethodHints(QtCore.Qt.ImhNone)
        self.oeTextBox.setObjectName(_fromUtf8("oeTextBox"))
        self.FilmographicTextBox = QtGui.QPlainTextEdit(self.centralwidget)
        self.FilmographicTextBox.setGeometry(QtCore.QRect(440, 160, 291, 41))
        self.FilmographicTextBox.setObjectName(_fromUtf8("FilmographicTextBox"))
        self.sourceAccessionTextBox = QtGui.QPlainTextEdit(self.centralwidget)
        self.sourceAccessionTextBox.setGeometry(QtCore.QRect(440, 230, 291, 41))
        self.sourceAccessionTextBox.setObjectName(_fromUtf8("sourceAccessionTextBox"))
        self.lineEdit_4 = QtGui.QLineEdit(self.centralwidget)
        self.lineEdit_4.setGeometry(QtCore.QRect(440, 60, 291, 20))
        self.lineEdit_4.setObjectName(_fromUtf8("lineEdit_4"))
        self.lineEdit_5 = QtGui.QLineEdit(self.centralwidget)
        self.lineEdit_5.setGeometry(QtCore.QRect(440, 140, 291, 20))
        self.lineEdit_5.setObjectName(_fromUtf8("lineEdit_5"))
        self.lineEdit_6 = QtGui.QLineEdit(self.centralwidget)
        self.lineEdit_6.setGeometry(QtCore.QRect(440, 210, 291, 20))
        self.lineEdit_6.setObjectName(_fromUtf8("lineEdit_6"))
        self.processButton = QtGui.QCommandLinkButton(self.centralwidget)
        self.processButton.setGeometry(QtCore.QRect(450, 370, 188, 41))
        self.processButton.setObjectName(_fromUtf8("processButton"))
        self.userComboBox.raise_()
        self.lineEdit_3.raise_()
        self.oeTextBox.raise_()
        self.FilmographicTextBox.raise_()
        self.sourceAccessionTextBox.raise_()
        self.lineEdit_4.raise_()
        self.lineEdit_5.raise_()
        self.lineEdit_6.raise_()
        self.processButton.raise_()
        self.tabWidget.raise_()
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 877, 21))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(2)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(_translate("MainWindow", "IFI Irish Film Archive Post Digitisation Tool", None))
        self.filmCaptureInterventionsListBox.setSortingEnabled(False)
        __sortingEnabled = self.filmCaptureInterventionsListBox.isSortingEnabled()
        self.filmCaptureInterventionsListBox.setSortingEnabled(False)
        item = self.filmCaptureInterventionsListBox.item(0)
        item.setText(_translate("MainWindow", "Overscanning of image to capture optical track", None))
        item = self.filmCaptureInterventionsListBox.item(1)
        item.setText(_translate("MainWindow", "Monochrome setting enabled", None))
        item = self.filmCaptureInterventionsListBox.item(2)
        item.setText(_translate("MainWindow", "Spacing between reels not captured                      ", None))
        item = self.filmCaptureInterventionsListBox.item(3)
        item.setText(_translate("MainWindow", "Negative to positive", None))
        item = self.filmCaptureInterventionsListBox.item(4)
        item.setText(_translate("MainWindow", "White reference taken from frame", None))
        self.filmCaptureInterventionsListBox.setSortingEnabled(__sortingEnabled)
        self.lineEdit.setText(_translate("MainWindow", "Capture Interventions", None))
        __sortingEnabled = self.filmPreparationListBox.isSortingEnabled()
        self.filmPreparationListBox.setSortingEnabled(False)
        item = self.filmPreparationListBox.item(0)
        item.setText(_translate("MainWindow", "Splice and perforation assessment", None))
        item = self.filmPreparationListBox.item(1)
        item.setText(_translate("MainWindow", "Splice repairs", None))
        item = self.filmPreparationListBox.item(2)
        item.setText(_translate("MainWindow", "Leader added", None))
        item = self.filmPreparationListBox.item(3)
        item.setText(_translate("MainWindow", "Perforation repairs", None))
        item = self.filmPreparationListBox.item(4)
        item.setText(_translate("MainWindow", "Recanned", None))
        item = self.filmPreparationListBox.item(5)
        item.setText(_translate("MainWindow", "Cleaning", None))
        item = self.filmPreparationListBox.item(6)
        item.setText(_translate("MainWindow", "Mould removal", None))
        self.filmPreparationListBox.setSortingEnabled(__sortingEnabled)
        self.lineEdit_2.setText(_translate("MainWindow", "Preparation Actions", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.scanningTab), _translate("MainWindow", "Scanning", None))
        __sortingEnabled = self.tapeDeckList.isSortingEnabled()
        self.tapeDeckList.setSortingEnabled(False)
        item = self.tapeDeckList.item(0)
        item.setText(_translate("MainWindow", "Basement - DVW-500P", None))
        item = self.tapeDeckList.item(1)
        item.setText(_translate("MainWindow", "Basement - UVW something", None))
        item = self.tapeDeckList.item(2)
        item.setText(_translate("MainWindow", "Basement - J30", None))
        item = self.tapeDeckList.item(3)
        item.setText(_translate("MainWindow", "Basement - JH3", None))
        item = self.tapeDeckList.item(4)
        item.setText(_translate("MainWindow", "Edit Suite - JH3", None))
        item = self.tapeDeckList.item(5)
        item.setText(_translate("MainWindow", "Edit Suite - UVW", None))
        self.tapeDeckList.setSortingEnabled(__sortingEnabled)
        self.tapeFormatComboBox.setItemText(0, _translate("MainWindow", "Source Format", None))
        self.tapeFormatComboBox.setItemText(1, _translate("MainWindow", "Betacam SP", None))
        self.tapeFormatComboBox.setItemText(2, _translate("MainWindow", "Digital Betacam", None))
        self.tapeFormatComboBox.setItemText(3, _translate("MainWindow", "Mini DV", None))
        self.tapeWorkstationComboBox.setItemText(0, _translate("MainWindow", "Select Workstation", None))
        self.tapeWorkstationComboBox.setItemText(1, _translate("MainWindow", "Edit Suite 1", None))
        self.tapeWorkstationComboBox.setItemText(2, _translate("MainWindow", "Edit Suite 2", None))
        self.tapeWorkstationComboBox.setItemText(3, _translate("MainWindow", "Edit suite 3", None))
        self.tapeWorkstationComboBox.setItemText(4, _translate("MainWindow", "Ingest Station 1", None))
        self.tapeWorkstationComboBox.setItemText(5, _translate("MainWindow", "Ingest Station 2", None))
        self.ffv1CheckBox.setText(_translate("MainWindow", "Transcoded to FFV1/MKV?", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tapeTab), _translate("MainWindow", "Tape", None))
        __sortingEnabled = self.rawAudioInterventions.isSortingEnabled()
        self.rawAudioInterventions.setSortingEnabled(False)
        item = self.rawAudioInterventions.item(0)
        item.setText(_translate("MainWindow", "De-Noise", None))
        item = self.rawAudioInterventions.item(1)
        item.setText(_translate("MainWindow", "De-Click", None))
        item = self.rawAudioInterventions.item(2)
        item.setText(_translate("MainWindow", "De-Crackle", None))
        item = self.rawAudioInterventions.item(3)
        item.setText(_translate("MainWindow", "Spectral Repair", None))
        item = self.rawAudioInterventions.item(4)
        item.setText(_translate("MainWindow", "Phase Correction", None))
        item = self.rawAudioInterventions.item(5)
        item.setText(_translate("MainWindow", "Master Gain Adjustment", None))
        item = self.rawAudioInterventions.item(6)
        item.setText(_translate("MainWindow", "Gain Automation", None))
        item = self.rawAudioInterventions.item(7)
        item.setText(_translate("MainWindow", "EQ Adjustment", None))
        item = self.rawAudioInterventions.item(8)
        item.setText(_translate("MainWindow", "Dither", None))
        item = self.rawAudioInterventions.item(9)
        item.setText(_translate("MainWindow", "Resample to 48khz", None))
        item = self.rawAudioInterventions.item(10)
        item.setText(_translate("MainWindow", "Sync edit and consolidation", None))
        item = self.rawAudioInterventions.item(11)
        item.setText(_translate("MainWindow", "Fade added at head", None))
        item = self.rawAudioInterventions.item(12)
        item.setText(_translate("MainWindow", "Fade added at tail", None))
        item = self.rawAudioInterventions.item(13)
        item.setText(_translate("MainWindow", "Other", None))
        self.rawAudioInterventions.setSortingEnabled(__sortingEnabled)
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.rawAudioTab), _translate("MainWindow", "Raw Audio", None))
        __sortingEnabled = self.listWidget.isSortingEnabled()
        self.listWidget.setSortingEnabled(False)
        item = self.listWidget.item(0)
        item.setText(_translate("MainWindow", "Rescale via Frameflex", None))
        item = self.listWidget.item(1)
        item.setText(_translate("MainWindow", "Rescale via Baselight", None))
        item = self.listWidget.item(2)
        item.setText(_translate("MainWindow", "Set reference black and white via Baselight", None))
        item = self.listWidget.item(3)
        item.setText(_translate("MainWindow", "Set reference black and white via Baselight colour correction", None))
        item = self.listWidget.item(4)
        item.setText(_translate("MainWindow", "Local Scaling via Baselight", None))
        item = self.listWidget.item(5)
        item.setText(_translate("MainWindow", "Contrast Curve adjustment via Baselight", None))
        item = self.listWidget.item(6)
        item.setText(_translate("MainWindow", "Saturation adjustment via Baselight Hue Shift", None))
        item = self.listWidget.item(7)
        item.setText(_translate("MainWindow", "Hue Shift via Baselight Hue Shift", None))
        item = self.listWidget.item(8)
        item.setText(_translate("MainWindow", "Image Stabilisation via Avid No active image area lost", None))
        item = self.listWidget.item(9)
        item.setText(_translate("MainWindow", "Image Stabilisation via Avid but active image area lost", None))
        item = self.listWidget.item(10)
        item.setText(_translate("MainWindow", "Horizontal flipping", None))
        item = self.listWidget.item(11)
        item.setText(_translate("MainWindow", "Vertical flipping", None))
        item = self.listWidget.item(12)
        item.setText(_translate("MainWindow", "Damage removal via Paint effect", None))
        self.listWidget.setSortingEnabled(__sortingEnabled)
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.gradeTab), _translate("MainWindow", "Grade", None))
        self.userComboBox.setItemText(0, _translate("MainWindow", "Select User", None))
        self.userComboBox.setItemText(1, _translate("MainWindow", "Kieran O\'Leary", None))
        self.userComboBox.setItemText(2, _translate("MainWindow", "Brian Cash", None))
        self.userComboBox.setItemText(3, _translate("MainWindow", "Gavin Martin", None))
        self.userComboBox.setItemText(4, _translate("MainWindow", "Raelene Casey", None))
        self.userComboBox.setItemText(5, _translate("MainWindow", "Aaron Healy", None))
        self.userComboBox.setItemText(6, _translate("MainWindow", "Dean Kavanagh", None))
        self.lineEdit_3.setText(_translate("MainWindow", "User", None))
        self.oeTextBox.setStatusTip(_translate("MainWindow", "a", None))
        self.oeTextBox.setWhatsThis(_translate("MainWindow", "b", None))
        self.lineEdit_4.setText(_translate("MainWindow", "Object Entry Number eg OE6789", None))
        self.lineEdit_5.setText(_translate("MainWindow", "Filmographic Reference Number eg AF6789", None))
        self.lineEdit_6.setText(_translate("MainWindow", "Source Accession Number eg IFA-2010-1234", None))
        self.processButton.setText(_translate("MainWindow", "Process!", None))




#!/usr/bin/env python
from PyQt4 import QtGui, QtCore
import sys
import subprocess
import premisgui
import os
import filecmp
import hashlib
from glob import glob




class ExampleApp(QtGui.QMainWindow, premisgui.Ui_MainWindow):
    def __init__(self):
        global text
        global counter
        counter = 0
        
        super(self.__class__, self).__init__()
        self.setupUi(self)  # This is defined in design.py file automatically
        self.processButton.setEnabled(True)
        self.processButton.clicked.connect(self.encode)
        #self.oeTextBox.textChanged.connect(self.countup)
        #print text
        #items = []
        self.filmPreparationListBox.itemSelectionChanged.connect(self.getPrepList)
        self.filmCaptureInterventionsListBox.itemSelectionChanged.connect(self.getInterventionList)
        self.rawAudioInterventions.itemSelectionChanged.connect(self.getRawAudioInterventionsList)
        self.tapeWorkstationComboBox.activated[str].connect(self.getWorkstation)
        self.processButton.clicked.connect(self.closeIt)
        
        
    def closeIt(self): 
            self.close()     
    def getWorkstation(self):
        global tapeWorkstation
        tapeWorkstation = self.tapeWorkstationComboBox.currentText()    

    def getPrepList(self):
        global items
        items = []
        
        itemObjects = self.filmPreparationListBox.selectedItems()
        for i in itemObjects:
            items.append(str(i.text()))
        return items
    
    def getInterventionList(self):
        global interventions
        interventions = []
        
        interventionsObjects = self.filmCaptureInterventionsListBox.selectedItems()
        for i in interventionsObjects:
            interventions.append(str(i.text()))
        return interventions
        
    def getRawAudioInterventionsList(self):
        global rawAudiointerventions
        rawAudiointerventions = []
        
        rawAudiointerventionsObjects = self.rawAudioInterventions.selectedItems()
        for i in rawAudiointerventionsObjects:
            rawAudiointerventions.append(str(i.text()))
        return rawAudiointerventions
        
    def encode(self):
        global ifi_identifiersDict
        ifi_identifiersDict = {}
        user = self.userComboBox.currentText()
        oe = self.oeTextBox.toPlainText()
        filmographic = self.FilmographicTextBox.toPlainText()
        sourceAccession = self.sourceAccessionTextBox.toPlainText()
        #interventions = self.getInterventionList
        #items = self.getPrepLists
        
        
        if self.tabWidget.currentIndex() == 0:
            ifi_identifiersDict = {"workflow":"scanning","oe":str(oe), "filmographic":str(filmographic), "sourceAccession":str(sourceAccession), "interventions":interventions, "prepList":items, "user":str(user)}
            
        if self.tabWidget.currentIndex() == 1:
            ifi_identifiersDict = {"workflow":"tape", "oe":str(oe), "filmographic":str(filmographic), "sourceAccession":str(sourceAccession), "tapeWorkstation":str(tapeWorkstation)}
            
        elif self.tabWidget.currentIndex() == 2:
            ifi_identifiersDict = {"workflow":"rawaudio","oe":str(oe), "filmographic":str(filmographic), "sourceAccession":str(sourceAccession), "rawAudiointerventions":str(rawAudiointerventions)}
              
        return ifi_identifiersDict
        
        #items = self.getPrepList
        
        
        
def main():

    app = QtGui.QApplication(sys.argv)  # A new instance of QApplication
    form = ExampleApp()  # We set the form to be our ExampleApp (design)
    form.show()  # Show the form
    app.exec_()  # and execute the app
    
    return ifi_identifiersDict
    
if __name__ == '__main__':
    main()  # run the main function


#!/usr/bin/env python
'''
Runs Digital Forensic XML.
'''
import os
import sys
import argparse
import walk_to_dfxml
from lxml import etree


def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Prints Digital Forensics XML to your terminal'
        'Proof of concept - hashes are turned off for now. no logging etc..'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        'input',
        help='full path of input directory.'
    )
    parser.add_argument(
        '-o',
        help='full path to an output XML file'
    )
    parser.add_argument(
        '-n',
        action="store_true", help="Do not calculate any hashes"
    )
    parsed_args = parser.parse_args(args_)
    return parsed_args


def main(args_):
    '''
    Launches the functions that will print your digital forensics XML.
    Hashes are turned off by default.
    '''
    args = parse_args(args_)
    if args.o:
        if not args.o.endswith("xml"):
            print('output file must be XML')
    source = args.input
    os.chdir(source)
    if args.n:
        hash_arg = ["-n"]
    else:
        hash_arg = []
    output = walk_to_dfxml.main(hash_arg)
    parser = etree.XMLParser(remove_blank_text=True)
    dfxml_out = etree.fromstring((output), parser=parser)
    if args.o:
        with open(args.o, 'w') as xml_doc:
            xml_doc.write(etree.tostring(dfxml_out, pretty_print=True).decode('ascii'))
    else:
        print(etree.tostring(dfxml_out, pretty_print=True).decode('ascii'))


if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python3

import argparse
import subprocess
import sys
import os
from glob import glob
import pdb
import ififuncs

def set_options(args_):
    '''
    Parse command line options.
    '''
    parser = argparse.ArgumentParser(description='IFI Pro Res 4:2:2 ffmpeg Encoder.'
                                     ' Written by Kieran O\'Leary.')
    parser.add_argument('input')
    parser.add_argument(
                        '-hq',
                        action='store_true',help='-profile:v 3 aka Prores HQ')
    parser.add_argument(
                        '-yadif',
                        action='store_true',help='Yet Another DeInterlace Filter')
    parser.add_argument(
                        '-wide',
                        action='store_true',help='Adds 16:9 metadata flag')
    parser.add_argument(
                        '-scale',
                        help='Rescale video.'
                        ' Usage: -scale 1920x1080 or -scale 720x576 etc')
    parser.add_argument(
                        '-md5',
                        action='store_true',
                        help='Get md5 sidecar for your output file')
    parser.add_argument(
                        '-map',
                        action='store_true',
                        help='Force default mapping, eg. 1 audio/video stream')
    parser.add_argument(
                        '-o',
                        help='Set output directory.'
                        'The default directory is the same as the input directory')
  
    parsed_args = parser.parse_args(args_)
    return parsed_args

def main(args_):
    '''
    Launch the various functions that will make a h264/mp4 access copy.
    '''
    ififuncs.check_existence(['ffmpeg'])
    args = set_options(args_)
    prores_options = []
    
    if args.yadif:
        prores_options.append('-yadif')
    
    if args.scale:
        prores_options.append('-scale')
        width_height = args.scale

    number_of_effects =  len(prores_options)

     # Input, either file or firectory, that we want to process.
    input = args.input

    # Store the directory containing the input file/directory.
    wd = os.path.dirname(input)

    # Change current working directory to the value stored as "wd"
    os.chdir(wd)

    # Store the actual file/directory name without the full path.
    file_without_path = os.path.basename(input)

    # Check if input is a file.
    # AFAIK, os.path.isfile only works if full path isn't present.
    if os.path.isfile(file_without_path):
        video_files = []                       # Create empty list
        video_files.append(file_without_path)  # Add filename to list

    # Check if input is a directory.
    elif os.path.isdir(file_without_path):
        os.chdir(file_without_path)
        video_files = (
            glob('*.mov') +
            glob('*.mp4') +
            glob('*.mxf') +
            glob('*.mkv') +
            glob('*.avi')
        )

    # Prints some stuff if input isn't a file or directory.
    else:
        print("Your input isn't a file or a directory.")
    
                      
    for filename in video_files:
        #pdb.set_trace()
    
        if args.o:
            output = args.o + '/' + os.path.basename(filename) + "_prores.mov"
        else:
            output = filename + "_prores.mov"
        ffmpeg_args = [
            'ffmpeg',
            '-i', filename,
        ]
        pix_fmt = ififuncs.get_ffmpeg_fmt(filename, 'video')
        ffmpeg_args =   ['ffmpeg',
                '-i', filename,
                '-c:a', 'copy',]
        if ('rgb' in pix_fmt) or  ('gbr' in pix_fmt):
            ffmpeg_args.extend(['-c:v', 'prores_ks'])
        else:
            ffmpeg_args.extend(['-c:v', 'prores'])
        if not args.map:
            ffmpeg_args.append('-map')
            ffmpeg_args.append('0:a?')
            ffmpeg_args.append('-map')
            ffmpeg_args.append('0:v')
                
        if args.hq:
            ffmpeg_args.append('-profile:v')
            ffmpeg_args.append('3')
        if args.wide:
            ffmpeg_args.append('-aspect')
            ffmpeg_args.append('16:9')
        if args.yadif or args.scale:
        
            filter_options = '-vf'
        
            if args.yadif:
                filter_options += ' yadif'
              
            if args.scale:
                if number_of_effects > 1:
                    filter_options += (',scale=%s' % width_height)
                else:
                    filter_options += (' scale=%s' % width_height)
            
            filter_options = filter_options.split()
            for item in filter_options:
                ffmpeg_args.append(item)
        ffmpeg_args.append(output)
        print(ffmpeg_args)
        subprocess.call(ffmpeg_args)

if __name__ == "__main__":
    main(sys.argv[1:])



#!/usr/bin/env python

# Written by Kieran O'Leary, with a major review and overhaul/cleanup by Zach Kelling aka @Zeekay
# Makes a single ffv1.mkv

import subprocess
import sys
import filecmp
import os
import shutil
import csv
import time
import itertools
import getpass
from glob import glob
try:
    from ififuncs import set_environment
    from ififuncs import hashlib_manifest
    from ififuncs import make_mediatrace
    from ififuncs import make_mediainfo
    from ififuncs import get_mediainfo
    from ififuncs import append_csv
    from ififuncs import create_csv
    from ififuncs import generate_log
    from ififuncs import get_ffmpeg_fmt
except ImportError:
    print '*** ERROR - IFIFUNCS IS MISSING - *** \n'
    'Makeffv1 requires that ififuncs.py is located in the same directory'
    ' as some functions are located in that script -'
    'https://github.com/kieranjol/IFIscripts/blob/master/ififuncs.py'
    sys.exit()

def read_non_comment_lines(infile):
    # Adapted from Andrew Dalke - http://stackoverflow.com/a/8304087/2188572
    for lineno, line in enumerate(infile):
        #if line[:1] != "#":
        yield lineno, line

def get_input():
    if len(sys.argv) < 2:
        print 'IFI FFV1.MKV SCRIPT'
        print 'USAGE: PYTHON makeffv1.py FILENAME'
        print 'OR'
        print 'USAGE: PYTHON makeffv1.py DirectoryNAME'
        print 'If input is a directory, all files will be processed'
        print 'If input is a file, only that file will be processed'
        sys.exit()
    else:
        # Input, either file or firectory, that we want to process.
        input = sys.argv[1]
        # Store the directory containing the input file/directory.
        wd = os.path.dirname(input)
        # Change current working directory to the value stored as "wd"
        os.chdir(os.path.abspath(wd))
        # Store the actual file/directory name without the full path.
        file_without_path = os.path.basename(input)
        csv_report_filename = (
            os.path.basename(input)
            + 'makeffv1_results'
            + time.strftime("_%Y_%m_%dT%H_%M_%S") + '.csv'
            )
        # Check if input is a file.
        # AFAIK, os.path.isfile only works if full path isn't present.
        if os.path.isfile(file_without_path):
            print "single file found"
            video_files = []                       # Create empty list
            video_files.append(file_without_path)  # Add filename to list
        # Check if input is a directory.
        elif os.path.isdir(file_without_path):
            os.chdir(file_without_path)
            video_files = (
                glob('*.mov')
                + glob('*.mp4')
                + glob('*.mxf')
                + glob('*.mkv')
                + glob('*.avi')
                + glob('*.y4m')
                )
        else:
            print "Your input isn't a file or a directory."
            print "What was it? I'm curious."
        # temporary hack to stop makeffv1 from processing DV
        dv_test = []
        for test_files in video_files:
            codec =  get_mediainfo(
                'codec', '--inform=Video;%Codec%',
                 test_files
                 ).rstrip()
            if codec == 'DV':
                dv_test.append(test_files)
                print 'DV file found, skipping'
        for i in dv_test:
            if i in video_files:
                video_files.remove(i)
        create_csv(
            csv_report_filename,
            (
                'FILENAME', 'Lossless?',
                'Source size in bits', 'FFV1 size in bits',
                ' Compression ratio'
                )
            )
        return video_files, csv_report_filename
def make_ffv1(video_files, csv_report_filename):
    for filename in video_files: #loop all files in directory
        filenoext = os.path.splitext(filename)[0]
        # Generate new directory names
        metadata_dir = "%s/metadata" % filenoext
        log_dir = "%s/logs" % filenoext
        data_dir = "%s/objects" % filenoext
        # Actually create the directories.
        os.makedirs(metadata_dir)
        os.makedirs(data_dir)
        os.makedirs(log_dir)
        #Generate filenames for new files.
        inputxml = "%s/%s_source_mediainfo.xml" % (
            metadata_dir, os.path.basename(filename)
            )
        inputtracexml = "%s/%s_source_mediatrace.xml" % (
            metadata_dir, os.path.basename(filename)
            )
        output = "%s/%s.mkv" % (
            data_dir, os.path.splitext(os.path.basename(filename))[0]
            )
        # Generate filename of ffv1.mkv without the path.
        outputfilename = os.path.basename(output)
        outputxml = "%s/%s_mediainfo.xml" % (metadata_dir, outputfilename)
        outputtracexml = "%s/%s_mediatrace.xml" % (metadata_dir, outputfilename)
        fmd5 = "%s/%s_source.framemd5" % (
            metadata_dir, os.path.basename(filename)
            )
        fmd5ffv1 = "%s/%s_ffv1.framemd5" % (metadata_dir, outputfilename)
        log = "%s/%s_log.log" %  (log_dir, filename)
        generate_log(log, 'Input = %s' % filename)
        generate_log(log, 'Output = %s' % output)
        generate_log(
            log, 'makeffv1.py transcode to FFV1 and framemd5 generation of source started.'
            )
        ffv1_logfile = log_dir + '/%s_ffv1_transcode.log' % filename
        ffv1_env_dict = set_environment(ffv1_logfile)
        par = subprocess.check_output(
            [
                'mediainfo', '--Language=raw', '--Full',
                "--Inform=Video;%PixelAspectRatio%", filename
            ]
            ).rstrip()
        field_order = subprocess.check_output(
            [
                'mediainfo', '--Language=raw',
                '--Full', "--Inform=Video;%ScanType%", filename
            ]
            ).rstrip()
        height = subprocess.check_output(
            [
                'mediainfo', '--Language=raw',
                '--Full', "--Inform=Video;%Height%",
                filename
            ]
            ).rstrip()
        # Transcode video file writing frame md5 and output appropriately
        ffv1_command = [
            'ffmpeg',
            '-i', filename,
            '-c:v', 'ffv1',        # Use FFv1 codec
            '-g', '1',              # Use intra-frame only aka ALL-I aka GOP=1
            '-level', '3',          # Use Version 3 of FFv1
            '-c:a', 'copy',         # Copy and paste audio bitsream with no transcoding
            '-map', '0',
            '-dn',
            '-report',
            '-slicecrc', '1',
            '-slices', '16',
            ]
        # check for FCP7 lack of description and PAL
        if par == '1.000':
            if field_order == '':
                if height == '576':
                    ffv1_command += [
                        '-vf',
                        'setfield=tff, setdar=4/3'
                        ]
        ffv1_command += [
            output,
            '-f', 'framemd5', '-an',  # Create decoded md5 checksums for every frame of the input. -an ignores audio
            fmd5
            ]
        print ffv1_command
        subprocess.call(ffv1_command, env=ffv1_env_dict)
        generate_log(
            log, 'makeffv1.py transcode to FFV1 and framemd5 generation completed.'
            )
        generate_log(
            log, 'makeffv1.py Framemd5 generation of output file started.'
            )
        fmd5_logfile = log_dir + '/%s_framemd5.log' % outputfilename
        fmd5_env_dict = set_environment(fmd5_logfile)
        pix_fmt = get_ffmpeg_fmt(filename, 'video')
        fmd5_command = [
            'ffmpeg',    # Create decoded md5 checksums for every frame
            '-i', output,
            '-report',
            '-pix_fmt', pix_fmt,
            '-f', 'framemd5', '-an',
            fmd5ffv1
            ]
        print fmd5_command
        subprocess.call(fmd5_command, env=fmd5_env_dict)
        generate_log(
            log,
            'makeffv1.py Framemd5 generation of output file completed'
            )
        source_video_size = get_mediainfo(
            'source_video_size', "--inform=General;%FileSize%", filename
            )
        ffv1_video_size = get_mediainfo(
            'ffv1_video_size', '--inform=General;%FileSize%', output
            )
        compression_ratio = float(source_video_size) / float(ffv1_video_size)
        if os.path.basename(sys.argv[0]) == 'makeffv1.py':
            try:
                shutil.copy(sys.argv[0], log_dir)
            except IOError:
                pass
        print 'Generating mediainfo xml of input file and saving it in %s' % inputxml
        make_mediainfo(inputxml, 'mediaxmlinput', filename)
        print 'Generating mediainfo xml of output file and saving it in %s' % outputxml
        make_mediainfo(outputxml, 'mediaxmloutput', output)
        print 'Generating mediatrace xml of input file and saving it in %s' % inputtracexml
        make_mediatrace(inputtracexml, 'mediatracexmlinput', filename)
        print 'Generating mediatrace xml of output file and saving it in %s' % outputtracexml
        make_mediatrace(outputtracexml, 'mediatracexmloutput', output)
        source_parent_dir = os.path.dirname(os.path.abspath(filename))
        manifest = '%s/%s_manifest.md5' % (source_parent_dir, filenoext)
        generate_log(log, 'makeffv1.py MD5 manifest started')
        checksum_mismatches = []
        with open(fmd5) as f1:
            with open(fmd5ffv1) as f2:
                for (lineno1, line1), (lineno2, line2) in itertools.izip(
                        read_non_comment_lines(f1),
                        read_non_comment_lines(f2)
                        ):
                    if line1 != line2:
                        if 'sar' in line1:
                            checksum_mismatches = ['sar']
                        else:
                            checksum_mismatches.append(1)
        if len(checksum_mismatches) == 0:
            print 'LOSSLESS'
            append_csv(
                csv_report_filename, (
                    output,
                    'LOSSLESS', source_video_size,
                    ffv1_video_size, compression_ratio
                    )
                )
            generate_log(log, 'makeffv1.py Transcode was lossless')
        elif len(checksum_mismatches) == 1:
            if checksum_mismatches[0] == 'sar':
                print 'Image content is lossless,'
                ' Pixel Aspect Ratio has been altered.'
                ' Update ffmpeg in order to resolve the PAR issue.'
                append_csv(
                    csv_report_filename,
                    (
                        output,
                        'LOSSLESS - different PAR',
                        source_video_size, ffv1_video_size, compression_ratio
                        )
                    )
                generate_log(
                    log,
                    'makeffv1.py Image content is lossless but Pixel Aspect Ratio has been altered.Update ffmpeg in order to resolve the PAR issue.'
                    )
        elif len(checksum_mismatches) > 1:
            print 'NOT LOSSLESS'
            append_csv(
                csv_report_filename,
                (
                    output, 'NOT LOSSLESS',
                    source_video_size, ffv1_video_size, compression_ratio
                    )
                )
            generate_log(log, 'makeffv1.py Not Lossless.')
        hashlib_manifest(filenoext, manifest, source_parent_dir)
        if filecmp.cmp(fmd5, fmd5ffv1, shallow=False):
            print "YOUR FILES ARE LOSSLESS YOU SHOULD BE SO HAPPY!!!"
        else:
            print "The framemd5 text files are not completely identical."
            " This may be because of a lossy transcode,"
            " or a change in metadata, most likely pixel aspect ratio."
            " Please analyse the framemd5 files for source and output."

def main():
    video_files, csv_report_filename = get_input()
    make_ffv1(video_files, csv_report_filename)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
'''
Analyses the CSV file reports from Strongbox.
Accepts an identifier input, at least the package ID but
the UUID would also be useful.
The script then finds the relevant entries, harvests the checksums and
stores them as a regular manifest.
It would make sense to also accept an existing sha512 manifest as an argparse
so that the script can tell if they are identical.

'''
import os
import sys
import collections
import argparse
import unicodedata
import ififuncs

def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Analyses the CSV file reports from Strongbox.'
        'Prints the output to the terminal if the -manifest option is not used'
        'if the -manifest option is used, just the differences, if any, will appear on screen'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        '-csv', help='Path to the strongbox CSV file.'
    )
    parser.add_argument(
        '-i',
        help='Path of the parent folder containing the accessioned packages'
    )
    parsed_args = parser.parse_args(args_)
    return parsed_args

def diff_manifests(manifest, strongbox_list):
    '''
    Compare the list of strongbox hashes to the original AIP manifest.
    '''
    print('\nStrongbox_fixity - IFIscripts')
    print('Analysing %s\n' % manifest)
    with open(manifest, 'r') as original_manifest:
        aip_manifest = original_manifest.read().splitlines()
    # A list of items in strongbox, that are different in aip sha512 manifest
    strongbox_check = [item for item in strongbox_list if unicodedata.normalize('NFD', item) not in aip_manifest]
    new_manifest = []
    # A list of items in the AIP manifest, that are different in the strongbox manifest
    aip_check =  [item for item in aip_manifest if unicodedata.normalize('NFD', item) not in strongbox_list]
    # check if the files are actually on the strongbox
    if len(strongbox_list) == 0:
        print('ERROR ***************************************')
        print('ERROR ***************************************The files are not on strongbox!!')
    # checks if everything in the strongbox list is in the aip manifest.
    elif len(strongbox_check) == 0:
        print('All files in the strongbox manifest are present in your AIP manifest and the hashes validate')
    else:
        for i in strongbox_check:
            print('%s is different from the strongbox_csv to the AIP manifest' % i)
    if len(aip_check) == 0:
        print('All files in the AIP manifest are present in your strongbox manifest and the hashes validate')
    else:
        for i in strongbox_check:
            print('%s is different from the AIP manifest to the Strongbox manifest' % i)
    print('Analysis complete\n')
def find_checksums(csv_file, identifier):
    '''
    Finds the relevant entries in the CSV and prints to terminal
    '''
    csv_dict = ififuncs.extract_metadata(csv_file)
    manifest_lines = []
    for items in csv_dict:
        for x in items:
            if type(x) in [collections.OrderedDict, dict]:
                if identifier in x['path']:
                    identifier_string = "/%s/" % identifier
                    manifest_line = x['hash_code'] + '  ' + x['path'].replace(identifier_string, '')
                    manifest_lines.append(manifest_line)
    strongbox_list = sorted(manifest_lines, key=lambda x: (x[130:]))
    return strongbox_list

def find_manifest(source):
    '''
    Recursively search through a package for a sha512 package.
    '''
    for root, dirnames, filenames in os.walk(source):
        for files in filenames:
            if files.endswith('_manifest-sha512.txt'):
                return os.path.join(root, files)

def main(args_):
    args = parse_args(args_)
    csv_file = args.csv
    source = args.i
    package_list = sorted(os.listdir(source))
    for package in package_list:
        full_path = os.path.join(source, package)
        if os.path.isdir(full_path):
            basename = os.path.basename(package)
            if package[:3] == 'aaa':
                strongbox_list = find_checksums(csv_file, package)
                manifest = find_manifest(full_path)
                diff_manifests(manifest, strongbox_list) # manifest needs to be declared here
                '''
                for i in strongbox_list:
                    print i
                '''
if __name__ == '__main__':
    main(sys.argv[1:])




#!/usr/bin/env python

import subprocess
import sys
import os
from glob import glob
import datetime
import time
import csv

            
def get_filenames(directory, log_filename_alteration):
    os.chdir(directory)
    tiff_check = glob('*.tiff')
    dpx_check = glob('*.dpx')
    if len(dpx_check) > 0:
        images = dpx_check     
    elif len(tiff_check) > 0:
        images = tiff_check
    else:  
        return 'none'    
    images.sort()
   
    if '864000' in images[0]:
        start_number = '864000'
    elif len(images[0].split("_")[-1].split(".")) > 2:
        start_number = images[0].split("_")[-1].split(".")[1]
        
    else:
        
        start_number = images[0].split("_")[-1].split(".")[0]
    container = images[0].split(".")[-1]
    if len(images[0].split("_")[-1].split(".")) > 2:
        numberless_filename = images[0].split(".")
        
    else:
        numberless_filename = images[0].split("_")[0:-1]
    
    ffmpeg_friendly_name = ''
    counter = 0
    if len(images[0].split("_")[-1].split(".")) > 2:
        numberless_filename = images[0].split(".")[0:-1]
        for i in numberless_filename[:-1]:
            ffmpeg_friendly_name += i + '.'
        print ffmpeg_friendly_name

    else:
        while  counter <len(numberless_filename) :
            ffmpeg_friendly_name += numberless_filename[counter] + '_'
            counter += 1

    image_seq_without_container = ffmpeg_friendly_name
    if len(images[0].split("_")[-1].split(".")) > 2:
        image_seq_without_container = ffmpeg_friendly_name[:-1] + ffmpeg_friendly_name[-1].replace('_', '.')
    start_number_length = len(start_number)
    number_regex = "%0" + str(start_number_length) + 'd.'
    ffmpeg_friendly_name += number_regex + '%s' % container
    info = [image_seq_without_container, start_number, container]
    return info


source_directory = sys.argv[1]
if not os.path.isdir(source_directory):
    print 'Input is not a directory. Please rerun the script, providing the parent directory of the image sequence as input\nfor example:\nplayerseq.py /volumes/fakefolder/parentdir'
    sys.exit()

source_parent_dir    = os.path.dirname(source_directory)
split_path           = os.path.split(os.path.basename(source_directory))[1]
info = get_filenames(source_directory, 'dpx_framemd5')

image_seq_without_container = info[0]
start_number                = info[1]
container                   = info[2]
start_number_length = len(start_number)
number_regex = "%0" + str(start_number_length) + 'd.'
mezzanine_dir            = '/Volumes/Media1/individual_exports'
audio_file = raw_input('Drag and drop the actual WAV file and press ENTER\n').rstrip()
dpx_filename                = image_seq_without_container + number_regex + container
seq2prores= ['ffmpeg','-f','image2','-framerate','24', '-start_number', start_number, '-i', source_directory + '/' + dpx_filename ,'-i', audio_file,'-c:v','prores','-profile:v', '3','-c:a','copy', mezzanine_dir + '/' + image_seq_without_container  + '_mezzanine.mov']
print seq2prores
subprocess.call(seq2prores)


#!/usr/bin/env python
import subprocess
import argparse
import sys
import os
import hashlib
import shutil
import uuid
import time
import uuid
from glob import glob
from ififuncs import hashlib_manifest
from ififuncs import get_date_modified
from premis import make_premis
from premis import write_premis
from premis import make_agent
from premis import make_event
from premis import setup_xml
from premis import create_representation
from premis import create_intellectual_entity


'''
1. Accepts directory as input
2. Looks for the wav file
3. in /audio subfolder, the only files should be the audio.wav and the log.txt
4. workhorse wav copy sent to desktop
5. premis xml created
6. audio framemd5 gets moved to /metadata/audio
7. audio mediainfo gets moved to /metadata/audio
8. log gets moved to /logs/audio
9. manifest for whole SIP in directory


usage = python rawbatch.py directory

'''
def set_environment(logfile):
    env_dict = os.environ.copy()
    # https://github.com/imdn/scripts/blob/0dd89a002d38d1ff6c938d6f70764e6dd8815fdd/ffmpy.py#L272
    env_dict['FFREPORT'] = 'file={}:level=48'.format(logfile)
    return env_dict

def make_mediainfo(xmlfilename, xmlvariable, inputfilename):
    with open(xmlfilename, "w+") as fo:
        xmlvariable = subprocess.check_output(['mediainfo',
                        '-f',
                        '--language=raw', # Use verbose output.
                        '--output=XML',
                        inputfilename])       #input filename
        fo.write(xmlvariable)

def remove_bad_files(root_dir):
    rm_these = ['.DS_Store', 'Thumbs.db', 'desktop.ini']
    for root, dirs, files in os.walk(root_dir):
        for name in files:
            path = os.path.join(root, name)
            for i in rm_these:
                if name == i:
                    print '***********************' + 'removing: ' + path
                    os.remove(path)


def get_user():
    user = ''
    if not user == '1' or user == '2':
        user =  raw_input('\n\n**** Who did the actual scanning?\nPress 1 or 2\n\n1. Brian Cash\n2. Gavin Martin\n' )
        while user not in ('1','2'):
            user =  raw_input('\n\n**** Who did the actual scanning?\nPress 1 or 2\n\n1. Brian Cash\n2. Gavin Martin\n')
    if user == '1':
        user = 'Brian Cash'
        print 'Hi Brian, I believe that we can move on from that water bottle message as I have changed my terrible ways'
        time.sleep(1)
    elif user == '2':
        user = 'Gavin Martin'
        print 'Hi Gavin, Have you renewed your subscription to American Cinematographer?'
        time.sleep(1)
    return user

def get_aeolight_workstation():
    aeolight_station = ''
    if not aeolight_station == '1' or aeolight_station == '2':
        aeolight_station =  raw_input('\n\n**** Where was AEO-Light run?\nPress 1 or 2\n\n1. telecine room mac\n2. CA machine\n' )
        while aeolight_station not in ('1','2'):
            aeolight_station =  raw_input('\n\n**** Where was AEO-Light run?\nPress 1 or 2\n\n1. telecine room mac\n2. CA machine\n')
    if aeolight_station == '1':
        aeolight_station = 'telecine'
    elif aeolight_station == '2':
        aeolight_station = 'ca_machine'
    return aeolight_station


def make_parser():
    parser = argparse.ArgumentParser(description='Workflow specific metadata generator.'
                                'Accepts a WAV file as input.'
                                ' Designed for a specific IFI Irish Film Archive workflow. '
                                'Written by Kieran O\'Leary.')
    parser.add_argument('input', help='file path of parent directory')
    parser.add_argument('-v', action='store_true', help='verbose mode - Display full ffmpeg information')
    return parser


def process_audio(input, args):
    total_process = 6
    desktop_dir = os.path.expanduser("~/Desktop/%s") % os.path.basename(input)
    parent_dir = os.path.dirname(input)
    root_dir = os.path.dirname(os.path.dirname(parent_dir))
    os.chdir(root_dir)
    metadata_dir = root_dir + '/metadata/audio'
    aeo_light_premislog = input + '.xml'
    if os.path.isfile(aeo_light_premislog):
        shutil.move(aeo_light_premislog, metadata_dir)
    logs_dir = 'logs/audio'
    aeo_raw_extract_wav_dir = root_dir + '/objects/audio'
    framemd5 = metadata_dir + '/' + os.path.basename(input) +'.framemd5'
    if os.path.isfile(framemd5):
        return 'x', 'x', 'x', 'x'
    logfile = logs_dir + '/%s_framemd5.log' % os.path.basename(input)
    process_counter = 1
    print 'Process %d of %d - Logfile of framemd5 ffmpeg process located in %s/%s' % (process_counter,total_process, root_dir, logfile)
    process_counter += 1
    normpath = os.path.normpath(root_dir)
    relative_path = normpath.split(os.sep)[-1]
    manifest =  root_dir + '/raw_sip_manifest.md5'
    filenoext = os.path.splitext(input)[0]
    inputxml =  inputxml  = "%s/%s_mediainfo.xml" % (metadata_dir,os.path.basename(input))
    make_mediainfo(inputxml,'mediaxmlinput',input)
    env_dict = set_environment(logfile)
    ffmpegcmd = ['ffmpeg',    # Create decoded md5 checksums for every frame of the ffv1 output
                            '-i',input,
                            '-report',]
    if not args.v:
        ffmpegcmd += ['-v', '0']
    ffmpegcmd +=    ['-f','framemd5',
                            framemd5 ]
    print 'Process %d of %d - Generating framemd5 values for source WAV' % (process_counter,total_process)
    process_counter += 1
    subprocess.call(ffmpegcmd,env=env_dict)
    print 'Process %d of %d - Creating a workhorse copy of source WAV on Desktop' % (process_counter,total_process)
    process_counter += 1
    shutil.copy(input, desktop_dir)
    print 'Process %d of %d - Checking if any unwanted files should be removed, eg .DS_Stores or desktop.ini/thumbs.db' % (process_counter,total_process)
    process_counter += 1
    remove_bad_files(root_dir)
    os.chdir(parent_dir)
    print 'Process %d of %d - Generating manifest' % (process_counter,total_process)
    process_counter += 1
    hashlib_manifest(root_dir, manifest, root_dir)
    return root_dir, process_counter, total_process, aeo_raw_extract_wav_dir


def premis_description(root_dir, process_counter, total_process, aeo_raw_extract_wav_dir, user, aeolight_workstation, audio_date_modified, intellectual_entity_uuid):
    source_directory = root_dir + '/objects/image'
    image_dir_list = os.listdir(source_directory)
    for image_files in image_dir_list:
        if not image_files[0] == '.':
            if image_files.endswith('.tiff'):
                first_image =  source_directory + '/' + image_files
                image_date_modified = get_date_modified(first_image)
                continue
    print 'Process %d of %d - Generating PREMIS XML file' % (process_counter,total_process)
    process_counter += 1
    representation_uuid = str(uuid.uuid4())
    premisxml, premis_namespace, doc, premis = setup_xml(source_directory)
    split_list = os.path.basename(root_dir).split('_')
    if 'ifard2016' in split_list[2]:
        split_list[2] = split_list[2].replace('ifard2016', 'IFA-(RD)2016-')
    elif 'ifard2017' in split_list[2]:
        split_list[2] = split_list[2].replace('ifard2017', 'IFA-(RD)2017-')
    audio_items = {"workflow":"raw audio","oe":split_list[0], "filmographic":split_list[1], "sourceAccession":split_list[2], "interventions":['placeholder'], "prepList":['placeholder'], "user":'Brian Cash'}
    image_items = {"workflow":"scanning","oe":split_list[0], "filmographic":split_list[1], "sourceAccession":split_list[2], "interventions":['placeholder'], "prepList":['placeholder'], "user":user}
    linking_representation_uuids = []
    xml_info    = make_premis(aeo_raw_extract_wav_dir, audio_items, premis, premis_namespace, premisxml, representation_uuid, 'nosequence')

    linking_representation_uuids.append(xml_info[2])
    xml_info    = make_premis(source_directory, image_items, premis, premis_namespace,premisxml, representation_uuid, 'sequence')
    image_uuids = xml_info[4]
    linking_representation_uuids.append(image_uuids)

    linking_representation_uuids.append(image_items['sourceAccession'])
    audio_file_uuid = linking_representation_uuids[0]
    create_intellectual_entity(premisxml, premis_namespace, doc, premis, audio_items, intellectual_entity_uuid)
    create_representation(premisxml, premis_namespace, doc, premis, audio_items,linking_representation_uuids, representation_uuid, 'sequence', intellectual_entity_uuid)
    doc         = xml_info[0]
    premisxml   = xml_info[1]
    premis = doc.getroot()
    extract_uuid                                = str(uuid.uuid4())
    capture_received_uuid                       = str(uuid.uuid4())
    audio_premis_checksum_uuid                  = str(uuid.uuid4())
    audio_framemd5_uuid                         = str(uuid.uuid4())
    scanning_uuid                               = str(uuid.uuid4())
    premis_checksum_uuid                        = str(uuid.uuid4())
    package_manifest_uuid                       = str(uuid.uuid4())
    aeolight_events = [extract_uuid]
    aeolightAgent                               = make_agent(premis,aeolight_events, 'bc3de900-3903-4764-ab91-2ce89977d0d2')
    hashlib_events                              = [audio_premis_checksum_uuid, premis_checksum_uuid, package_manifest_uuid]
    hashlibAgent                                = make_agent(premis,hashlib_events, '9430725d-7523-4071-9063-e8a6ac4f84c4')
    brian_events                                = [extract_uuid]
    if user == 'Brian Cash':
        brian_events += audio_premis_checksum_uuid,audio_framemd5_uuid,premis_checksum_uuid,package_manifest_uuid
        brian_events = [capture_received_uuid, scanning_uuid]
    elif user == 'Gavin Martin':
        brian_events += audio_premis_checksum_uuid,audio_framemd5_uuid,premis_checksum_uuid,package_manifest_uuid
        gavin_events = [capture_received_uuid, scanning_uuid]
        gavinAgent                                  = make_agent(premis,gavin_events, '9cab0b9c-4787-4482-8927-a045178c8e39')


    if user == 'Gavin Martin':
        script_user_Agent  = gavinAgent

    brianAgent                                  = make_agent(premis,brian_events, '0b96a20d-49f5-46e9-950d-4e11242a487e')
    if user == 'Brian Cash':
        script_user_Agent = brianAgent

    if aeolight_workstation == 'telecine':
        macMiniTelecineMachineAgent_events          = [extract_uuid, audio_premis_checksum_uuid, premis_checksum_uuid, audio_framemd5_uuid,package_manifest_uuid ]
        macMiniTelecineMachineAgent                 = make_agent(premis,macMiniTelecineMachineAgent_events, '230d72da-07e7-4a79-96ca-998b9f7a3e41')
        macMiniTelecineMachineOSAgent_events        = [extract_uuid, audio_premis_checksum_uuid, premis_checksum_uuid, audio_framemd5_uuid, package_manifest_uuid ]
        macMiniTelecineOSAgent                      = make_agent(premis,macMiniTelecineMachineOSAgent_events, '9486b779-907c-4cc4-802c-22e07dc1242f')
        transcoderMachine                           = make_agent(premis,[capture_received_uuid], '946e5d40-a07f-47d1-9637-def5cb7854ba')
        transcoderMachineOS                         = make_agent(premis,[capture_received_uuid], '192f61b1-8130-4236-a827-a194a20557fe')
        aeolight_computer = macMiniTelecineMachineAgent
        aeolight_OS = macMiniTelecineOSAgent
    elif aeolight_workstation == 'ca_machine':
        macMiniTelecineMachineAgent_events          = [audio_premis_checksum_uuid, premis_checksum_uuid, audio_framemd5_uuid,package_manifest_uuid ]
        macMiniTelecineMachineAgent                 = make_agent(premis,macMiniTelecineMachineAgent_events, '230d72da-07e7-4a79-96ca-998b9f7a3e41')
        macMiniTelecineMachineOSAgent_events        = [audio_premis_checksum_uuid, premis_checksum_uuid, audio_framemd5_uuid, package_manifest_uuid ]
        macMiniTelecineOSAgent                      = make_agent(premis,macMiniTelecineMachineOSAgent_events, '9486b779-907c-4cc4-802c-22e07dc1242f')
        transcoderMachine                           = make_agent(premis,[capture_received_uuid, extract_uuid], '946e5d40-a07f-47d1-9637-def5cb7854ba')
        transcoderMachineOS                         = make_agent(premis,[capture_received_uuid, extract_uuid], '192f61b1-8130-4236-a827-a194a20557fe')
        aeolight_computer = transcoderMachine
        aeolight_OS = transcoderMachineOS
    ffmpegAgent_events                          = [audio_framemd5_uuid]
    ffmpegAgent                                 = make_agent(premis,ffmpegAgent_events , 'ee83e19e-cdb1-4d83-91fb-7faf7eff738e')
    scannerAgent                                = make_agent(premis,[scanning_uuid], '1f4c1369-e9d1-425b-a810-6db1150955ba')
    scannerPCAgent                              = make_agent(premis,[scanning_uuid], 'ca731b64-638f-4dc3-9d27-0fc14387e38c')
    scannerLinuxAgent                           = make_agent(premis,[scanning_uuid], 'b22baa5c-8160-427d-9e2f-b62a7263439d')

    make_event(premis, 'creation', 'Film scanned to 12-bit RAW Bayer format and transcoded internally by ca731b64-638f-4dc3-9d27-0fc14387e38c to 16-bit RGB linear TIFF', [scannerAgent, script_user_Agent, scannerPCAgent, scannerLinuxAgent], scanning_uuid,xml_info[4], 'outcome', image_date_modified)
    make_event(premis, 'creation', 'TIFF image sequence is received via ethernet from ca731b64-638f-4dc3-9d27-0fc14387e38c and written to Disk', [transcoderMachine,transcoderMachineOS, script_user_Agent], capture_received_uuid,image_uuids,'outcome', image_date_modified)
    make_event(premis, 'creation', 'PCM WAV file extracted from overscanned image area of source TIFF files', [aeolightAgent, brianAgent, aeolight_computer, aeolight_OS ], extract_uuid,[audio_file_uuid], 'outcome',audio_date_modified)
    make_event(premis, 'message digest calculation', 'Whole file checksum of audio created for PREMIS XML', [hashlibAgent, brianAgent,macMiniTelecineMachineAgent, macMiniTelecineOSAgent], audio_premis_checksum_uuid,[audio_file_uuid], 'source', 'now')
    make_event(premis, 'message digest calculation', 'Frame level checksums of audio', [ffmpegAgent, brianAgent,macMiniTelecineMachineAgent, macMiniTelecineOSAgent], audio_framemd5_uuid,[audio_file_uuid], 'source', 'now' )

    make_event(premis, 'message digest calculation', 'Whole file checksums of image created for PREMIS XML', [hashlibAgent, brianAgent,macMiniTelecineMachineAgent, macMiniTelecineOSAgent], premis_checksum_uuid,[representation_uuid], 'source', 'now')
    make_event(premis, 'message digest calculation', 'Checksum manifest for whole package created', [hashlibAgent, brianAgent,macMiniTelecineMachineAgent, macMiniTelecineOSAgent], package_manifest_uuid,[representation_uuid], 'source', 'now' )
    write_premis(doc, premisxml)

def main():
    parser = make_parser()
    args = parser.parse_args()
    input = args.input
    user = get_user()
    aeolight_workstation = get_aeolight_workstation()
    for root, dirnames, filenames in os.walk(input):
        for files in filenames:
            if files.endswith('.wav'):
                root_dir, process_counter, total_process, aeo_raw_extract_wav_dir = process_audio(os.path.join(root,files), args)
                audio_date_modified = get_date_modified(os.path.join(root,files))
                if total_process == 'x':
                    continue
                else:
                    intellectual_entity_uuid = str(uuid.uuid4())
                    premis_description(root_dir,process_counter, total_process, aeo_raw_extract_wav_dir, user, aeolight_workstation, audio_date_modified, intellectual_entity_uuid)
            else:
                continue

if __name__ == '__main__':
    main()



#!/usr/bin/env python
import lxml.etree as ET
import subprocess
import sys
import os
import shutil
import argparse
import datetime
import time
import csv
import uuid
from glob import glob
from ififuncs import create_csv
from ififuncs import append_csv
from ififuncs import send_gmail
from ififuncs import hashlib_manifest
from ififuncs import diff_textfiles
from ififuncs import make_manifest
from ififuncs import generate_log
from ififuncs import make_desktop_logs_dir
from premis import make_premis
from premis import write_premis
from premis import make_agent
from premis import make_event
from premis import setup_xml
from premis import create_unit


'''''
Events:
md5 manifest created of source
framemd5 of source
tiff2dpx
framemd5 output
manifest of output
'''

def set_environment(logfile):
    env_dict = os.environ.copy()
    # https://github.com/imdn/scripts/blob/0dd89a002d38d1ff6c938d6f70764e6dd8815fdd/ffmpy.py#L272
    env_dict['FFREPORT'] = 'file={}:level=48'.format(logfile)
    return env_dict

def make_framemd5(directory, container, log_filename_alteration):
    os.chdir(directory)

    images = glob('*.%s' % container)
    batch_dir = os.path.basename(os.path.dirname(os.path.dirname(root_dir)))
    output_parent_directory = os.path.join(args.o, batch_dir)
    if not os.path.isdir(output_parent_directory):
        os.makedirs(output_parent_directory)

    numberless_filename = images[0].split("_")[0:-1]
    ffmpeg_friendly_name = ''
    counter = 0
    while  counter <len(numberless_filename) :
        ffmpeg_friendly_name += numberless_filename[counter] + '_'
        counter += 1
    output_dirname = output_parent_directory + '/' + ffmpeg_friendly_name + 'dpx_transcodes'
    try:
        os.makedirs(output_dirname + '/image')
        os.makedirs(output_dirname + '/image/logs')
        os.makedirs(output_dirname + '/image/md5')
        os.makedirs(output_dirname + '/image/dpx_files')
        os.makedirs(output_dirname + '/image/xml_files')

    except: OSError

    output = output_dirname + '/image/md5/%s%s.framemd5' % (ffmpeg_friendly_name,container)

    logfile = output_dirname + '/image/logs/%s%s.log' % (ffmpeg_friendly_name, log_filename_alteration)

    env_dict = set_environment(logfile)
    image_seq_without_container = ffmpeg_friendly_name
    ffmpeg_friendly_name += "%06d." + '%s' % container

    framemd5 = ['ffmpeg','-report','-f','image2', '-i', ffmpeg_friendly_name,'-f','framemd5',output]
    print framemd5
    subprocess.call(framemd5, env=env_dict)
    info = [output_dirname, output, image_seq_without_container, output_parent_directory]
    return info
def file_check(dir2check):
    os.chdir(dir2check)
    tiff_check = glob('*.tiff')
    dpx_check = glob('*.dpx')
    if len(dpx_check) > 0:
        print 'DPX sequence, not TIFF. Not processing'
        return 'DPX'
    elif len(tiff_check) > 0:
        return 'TIFF'
    else:
        print 'no images found'
        return 'none'
def remove_bad_files(root_dir):
    rm_these = ['.DS_Store', 'Thumbs.db', 'desktop.ini']
    for root, dirs, files in os.walk(root_dir):
        for name in files:
            path = os.path.join(root, name)
            for i in rm_these:
                if name == i:
                    print '***********************' + 'removing: ' + path
                    os.remove(path)

def premis_log(source_parent_dir, source_directory):
    split_list = os.path.basename(os.path.dirname(source_parent_dir)).split('_')
    premisxml, premis_namespace, doc, premis = setup_xml(source_directory)
    items = {"workflow":"scanning","oe":split_list[0], "filmographic":split_list[1], "sourceAccession":split_list[2], "interventions":['placeholder'], "prepList":['placeholder'], "user":user}
    premis = doc.getroot()
    framemd5_uuid                               = str(uuid.uuid4())
    final_sip_manifest_uuid                              = str(uuid.uuid4())
    a = doc.xpath('//ns:agentIdentifierValue',namespaces={'ns': premis_namespace})
    for i in a:
        if i.text == '9430725d-7523-4071-9063-e8a6ac4f84c4':
            linkingEventIdentifier      = create_unit(-1,i.getparent().getparent(),'linkingEventIdentifier')
            linkingEventIdentifierType = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierType')
            linkingEventIdentifierValue = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierValue')
            linkingEventIdentifierValue.text = final_sip_manifest_uuid
            linkingEventIdentifierType.text = 'UUID'
        elif i.text == 'ee83e19e-cdb1-4d83-91fb-7faf7eff738e':
            linkingEventIdentifier      = create_unit(-1,i.getparent().getparent(),'linkingEventIdentifier')
            linkingEventIdentifierType = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierType')
            linkingEventIdentifierValue = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierValue')
            linkingEventIdentifierValue.text = framemd5_uuid
            linkingEventIdentifierType.text = 'UUID'
    representation_uuid  = doc.findall('//ns:objectIdentifierValue',namespaces={'ns': premis_namespace})[0].text
    #ffmpegAgent                                 = make_agent(premis,[framemd5_uuid ], 'ee83e19e-cdb1-4d83-91fb-7faf7eff738e')
    make_event(premis, 'message digest calculation', 'Checksum manifest for whole package created', [['UUID','9430725d-7523-4071-9063-e8a6ac4f84c4' ]],final_sip_manifest_uuid,[representation_uuid], 'source', 'now')
    make_event(premis, 'message digest calculation', 'Frame level checksums of images', [['UUID','ee83e19e-cdb1-4d83-91fb-7faf7eff738e' ]], framemd5_uuid, [representation_uuid], 'source', 'now' )
    write_premis(doc, premisxml)

parser = argparse.ArgumentParser(description='DPX2TIFF specific workflow for IFI'
                                ' Written by Kieran O\'Leary.')
parser.add_argument(
                    'input', nargs='+',
                    help='full path of input directory'
                    )
parser.add_argument(
                    '-o',
                    help='full path of output directory', required=True)
args = parser.parse_args()
print args
desktop_logs_dir = make_desktop_logs_dir()
csv_report_filename = os.path.join(desktop_logs_dir, 'dpx_transcode_report' + time.strftime("_%Y_%m_%dT%H_%M_%S") + '.csv')

#permission for correct directories sought from user
permission = ''
all_files = args.input
if not permission == 'y' or permission == 'Y':
    print '\n\n**** All TIFF sequences within these directories will be converted to DPX.\n'
    for i in all_files:
        print i
    permission =  raw_input('\n**** These are the directories that wil be turned into DPX. \n**** If this looks ok, please press Y, otherwise, type N\n' )
    while permission not in ('Y','y','N','n'):
        permission =  raw_input('\n**** These are the directories that wil be turned into DPX. \n**** If this looks ok, please press Y, otherwise, type N\n')
    if permission == 'n' or permission == 'N':
        print 'Exiting at your command- Cheerio for now'
        sys.exit()
    elif permission =='y' or permission == 'Y':
        print 'Ok so!'
        
#user identity sought for accurate premis documentation
user = ''
if not user == '1' or user == '2'or user == '3':
    user =  raw_input('\n\n**** Who are you?\nPress 1 or 2 or 3\n\n1. Brian Cash\n2. Gavin Martin\n3. Raelene Casey\n' )
    while user not in ('1','2','3'):
        user =  raw_input('\n\n**** Who are you?\nPress 1 or 2 or 3\n\n1. Brian Cash\n2. Gavin Martin\n3. Raelene Casey\n')
if user == '1':
    user = 'Brian Cash'
    print 'Hi Brian, Congratulations on becoming a father!!!'
elif user == '2':
    user = 'Gavin Martin'
    print 'Hi Gavin, Have you renewed your subscription to American Cinematographer?'
elif user == '3':
    user = 'Raelene Casey'
    print 'Hi Raelene, Brian must be out of the office'
    time.sleep(1)

create_csv(csv_report_filename, ('Sequence Name', 'Lossless?', 'Start time', 'Finish Time'))
for source_directory in all_files:
    for root,dirnames,filenames in os.walk(source_directory):
            source_directory = root
            if not file_check(source_directory) == 'TIFF':
                append_csv(csv_report_filename, (source_directory,'EMPTY DIRECTORY - SKIPPED', 'n/a', 'n/a'))
                continue

            root_dir = os.path.dirname(os.path.dirname(root))
            general_log = root_dir + '/logs/image/%s_image_log.log' % os.path.basename(root_dir)
            generate_log(general_log, 'Input = %s' % root)
            remove_bad_files(source_directory)
            source_parent_dir           = os.path.dirname(source_directory)
            normpath                    = os.path.normpath(source_directory)
            relative_path               = normpath.split(os.sep)[-1]
            split_path                  = os.path.split(os.path.basename(source_directory))[1]
            start                       = datetime.datetime.now()
            source_manifest             = root_dir + '/%s_manifest.md5' % relative_path
            generate_log(general_log, 'Generating source manifest via md5deep and storing as  %s' % source_manifest)
            make_manifest(root_dir, root_dir, source_manifest)
            info                        = make_framemd5(source_directory, 'tiff', 'tiff_framemd5')
            output_dirname              = info[0]
            source_textfile             = info[1]
            fmd5copy                    = root_dir + '/metadata/image'
            shutil.copy(source_textfile,fmd5copy )
            image_seq_without_container = info[2]
            output_parent_directory     = info[3]
            tiff_filename               = image_seq_without_container + "%06d.tiff"
            dpx_filename                = image_seq_without_container + "%06d.dpx"
            logfile                     = output_dirname + '/image/logs/%sdpx_transcode.log' % image_seq_without_container
            env_dict                    = set_environment(logfile)
            generate_log(general_log, 'Starting TIFF to DPX transcode')
            tiff2dpx                    = ['ffmpegnometadata','-report','-f','image2','-framerate','24', '-i', tiff_filename ,output_dirname +  '/image/dpx_files' '/' + dpx_filename]
            print tiff2dpx
            subprocess.call(tiff2dpx,env=env_dict)
            generate_log(general_log, 'TIFF to DPX transcode complete')
            parent_basename =  os.path.basename(output_dirname)
            manifest_textfile = os.path.dirname(output_dirname) + '/' +  parent_basename + '_manifest.md5'
            generate_log(general_log, 'Generating destination manifest via md5deep and storing as  %s' % manifest_textfile)
            other = make_framemd5(output_dirname + '/image/dpx_files', 'dpx', 'dpx_framemd5')
            other_textfile = other[1]
            judgement = diff_textfiles(source_textfile, other_textfile)
            generate_log(general_log, 'Outcome of transcode was:  %s' % judgement)
            make_manifest(output_parent_directory, os.path.basename(output_dirname), manifest_textfile)
            source_metadata_dir = root_dir + '/metadata/image'
            shutil.copy(source_textfile, source_metadata_dir + '/%s' % os.path.basename(source_textfile))
            finish = datetime.datetime.now()
            '''
            begin premis
            '''
            premis_log(source_parent_dir, source_directory)

            append_csv(csv_report_filename, (parent_basename,judgement, start, finish))



#!/usr/bin/env python3
'''
Concatenates video files using FFmpeg stream copy for general use but
particularly for XDCAM workflows in the IFI Irish Film Institute.
Uses mkvpropedit to insert chapter markers for each source file.
Optionally wraps the file into a package structure with checksum manifests.

Written by Kieran O'Leary.
'''
import sys
import subprocess
import os
import argparse
import time
import shutil
import sipcreator
import ififuncs

def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Concatenate video files using ffmpeg stream copy'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        '-i', nargs='+',
        help='full path of input directory', required=True
    )
    parser.add_argument(
        '-o', '-output',
        help='full path of output directory', required=True
    )
    parser.add_argument(
        '-r', '-recursive',
        help='recursively process all files in subdirectories. This could be potentially a disaster - so use with caution or with XDCAM', action='store_true'
    )
    parser.add_argument(
        '--no-sip',
        help='Do not run sipcreator.py on the resulting file.', action='store_true'
    )
    parser.add_argument(
        '-user',
        help='Declare who you are. If this is not set, you will be prompted.')
    parser.add_argument(
        '-oe',
        help='Enter the Object Entry number for the representation.SIP will be placed in a folder with this name.'
    )
    parser.add_argument(
        '-mov',
        help='Uses MOV container instead of Matroska', action='store_true'
    )
    parser.add_argument(
        '-nochapters',
        help='Skips the mkvpropedit chapter creation function', action='store_true'
    )
    parsed_args = parser.parse_args(args_)
    return parsed_args


def ffmpeg_concat(concat_file, args, uuid, container):
    '''
    Launch the actual ffmpeg concatenation command.
    '''
    fmd5_logfile = os.path.join(args.o, '%s_concat.log' % uuid).replace('\\', '\\\\').replace(':', '\:')
    fmd5_env_dict = ififuncs.set_environment(fmd5_logfile)
    print( fmd5_logfile)
    print( fmd5_env_dict)
    cmd = [
        'ffmpeg', '-report', '-f', 'concat', '-safe', '0',
        '-i', concat_file,
        '-c', 'copy', '-map', '0:v', '-map', '0:a?',
        os.path.join(args.o, '%s.%s' % (uuid, container)),
        '-f', 'md5', '-map', '0:v', '-map', '0:a?','-c', 'copy',  '-'
    ]
    print(cmd)
    source_bitstream_md5 = subprocess.check_output(
        cmd, env=fmd5_env_dict
    )
    return source_bitstream_md5.rstrip(), fmd5_logfile.replace('\\\\', '\\').replace('\:', ':')

def recursive_file_list(video_files):
    '''
    Recursively searches through directories for AV files and adds to a list.
    '''
    # check if all inputs are actually directories
    recursive_list = []
    for directory in video_files:
        if not os.path.isdir(directory):
            print( 'You have selected the recursive option, but not all of your inputs are directories.')
            sys.exit()
        else:
            for root, _, filenames in os.walk(directory):
                for filename in filenames:
                    if filename.endswith(('.MP4', '.mp4', '.mov', '.mkv', '.mxf', 'MXF')):
                        recursive_list.append(os.path.join(root, filename))
    print(recursive_list)
    return recursive_list

def make_chapters(video_files):
    '''
    Use mkvpropedit to insert chapter markers for each source video.
    Each chapter's name will reflect the source filename of each clip.
    '''
    millis = ififuncs.get_milliseconds(video_files[0])
    timestamp = ififuncs.convert_millis(int(millis))
    chapter_list = [['00:00:00.000', os.path.basename(video_files[0])], [timestamp, os.path.basename(video_files[1])]]
    count = 2
    for video in video_files[1:]:
        millis += ififuncs.get_milliseconds(video)
        timestamp = ififuncs.convert_millis(int(millis))
        if count == len(video_files):
            continue
        else:
            chapter_list.append([timestamp, os.path.basename(video_files[count])])
        count+=1
    chapter_counter = 1
    # uh use a real path/filename.
    with open('chapters.txt', 'w') as fo:
        for i in chapter_list:
            fo.write('CHAPTER%s=%s\nCHAPTER%sNAME=%s\n' % (str(chapter_counter).zfill(2), i[0], str(chapter_counter).zfill(2), i[1]))
            chapter_counter += 1


def main(args_):
    '''
    Launches the functions that prepare and execute the concatenation.
    '''
    ififuncs.check_existence(['ffmpeg', 'mkvpropedit', 'mediainfo'])
    uuid = ififuncs.create_uuid()
    args = parse_args(args_)
    print(args)
    log_name_source = os.path.join(args.o, '%s_concat_log.log' % time.strftime("_%Y_%m_%dT%H_%M_%S"))
    ififuncs.generate_log(log_name_source, 'concat.py started.')
    if args.mov:
        container = 'mov'
    else:
        container = 'mkv'
    ififuncs.generate_log(
        log_name_source,
        'eventDetail=concat.py %s' % ififuncs.get_script_version('concat.py'))
    ififuncs.generate_log(
        log_name_source,
        'Command line arguments: %s' % args
    )
    if args.user:
        user = args.user
    else:
        user = ififuncs.get_user()
    if args.oe:
        if args.oe[:2] != 'oe':
            print('First two characters must be \'oe\' and last four characters must be four digits')
            object_entry = ififuncs.get_object_entry()
        elif len(args.oe[2:]) not in range(4, 6):
            print('First two characters must be \'oe\' and last four characters must be four digits')
            object_entry = ififuncs.get_object_entry()
        elif not args.oe[2:].isdigit():
           object_entry = ififuncs.get_object_entry()
           print('First two characters must be \'oe\' and last four characters must be four digits')
        else:
            object_entry = args.oe
    else:
        object_entry = ififuncs.get_object_entry()
    ififuncs.generate_log(
        log_name_source,
        'EVENT = agentName=%s' % user
    )
    source_uuid_check = ''
    if os.path.isfile(args.i[0]):
        source_uuid = ififuncs.get_source_uuid()
    elif os.path.isdir(args.i[0]):
        source_uuid_check = ififuncs.check_for_uuid(args)
    if source_uuid_check == False:
        source_uuid = ififuncs.get_source_uuid()
    else: source_uuid = source_uuid_check
    ififuncs.generate_log(
        log_name_source,
        'Relationship, derivation, has source=%s' % source_uuid
    )
    video_files = args.i
    concat_file = ififuncs.get_temp_concat('concat_stuff')
    ififuncs.generate_log(
        log_name_source,
        'concatenation file=%s' % concat_file)
    if args.r:
        video_files = recursive_file_list(video_files)
    video_files = ififuncs.sanitise_filenames(video_files)
    for source_files in video_files:
        ififuncs.generate_log(
            log_name_source,
            'source_files = %s' % source_files)
    make_chapters(video_files)
    ififuncs.concat_textfile(video_files, concat_file)
    ififuncs.generate_log(
        log_name_source,
        'EVENT = Concatenation, status=started, eventType=Creation, agentName=ffmpeg, eventDetail=Source media concatenated into a single file output=%s' % os.path.join(args.o, '%s.%s' % (uuid, container)))
    source_bitstream_md5, fmd5_logfile = ffmpeg_concat(concat_file, args, uuid, container)
    output_file = os.path.join(args.o, '%s.%s' % (uuid, container))
    ififuncs.generate_log(
        log_name_source,
        'EVENT = Concatenation, status=finished, eventType=Creation, agentName=ffmpeg, eventDetail=Source media concatenated into a single file output=%s' % os.path.join(args.o, '%s.%s' % (uuid, container)))
    ififuncs.generate_log(
        log_name_source,
        'EVENT = losslessness verification, status=started, eventType=messageDigestCalculation, agentName=ffmpeg, eventDetail=MD5s of AV streams of output file generated for validation')
    validation_logfile = os.path.join(args.o, '%s_validation.log' % uuid).replace('\\', '\\\\').replace(':', '\:')
    validation_env_dict = ififuncs.set_environment(validation_logfile)
    output_bitstream_md5 = subprocess.check_output([
        'ffmpeg', '-report',
        '-i', output_file,
        '-f', 'md5', '-map', '0:v', '-map', '0:a?', '-c', 'copy', '-'
    ], env=validation_env_dict).rstrip()
    ififuncs.generate_log(
        log_name_source,
        'EVENT = losslessness verification, status=finished, eventType=messageDigestCalculation, agentName=ffmpeg, eventDetail=MD5s of AV streams of output file generated for validation')
    if source_bitstream_md5 == output_bitstream_md5:
        print( 'process appears to be lossless')
        print( source_bitstream_md5, output_bitstream_md5)
        ififuncs.generate_log(
        log_name_source,
        'EVENT = losslessness verification, eventOutcome=pass')
    else:
        print( 'something went wrong - not lossless!')
        print( source_bitstream_md5,output_bitstream_md5)
        ififuncs.generate_log(
        log_name_source,
        'EVENT = losslessness verification, eventOutcome=fail')
    if args.nochapters != True:
        subprocess.call(['mkvpropedit', output_file, '-c', 'chapters.txt'])
        ififuncs.generate_log(
            log_name_source,
            'EVENT = eventType=modification, agentName=mkvpropedit, eventDetail=Chapters added to file detailing start point of source clips.')
        ififuncs.concat_textfile(video_files, concat_file)
        with open(log_name_source, 'r') as concat_log:
            concat_lines = concat_log.readlines()
    if not args.no_sip:
        sipcreator_log, sipcreator_manifest = sipcreator.main(['-i', output_file, '-u', uuid, '-oe', object_entry, '-user', user, '-o', args.o])
        shutil.move(fmd5_logfile, os.path.dirname(sipcreator_log))
        shutil.move(validation_logfile.replace('\\\\', '\\').replace('\:', ':'), os.path.dirname(sipcreator_log))
        logs_dir = os.path.dirname(sipcreator_log)
        ififuncs.manifest_update(sipcreator_manifest, os.path.join(logs_dir, os.path.basename(fmd5_logfile)))
        ififuncs.manifest_update(sipcreator_manifest, os.path.join(logs_dir,(os.path.basename(validation_logfile.replace('\\\\', '\\').replace('\:', ':')))))
        ififuncs.merge_logs(log_name_source, sipcreator_log, sipcreator_manifest)

if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python
import subprocess
import sys
import os
import shutil
import argparse
import datetime
import time
import csv
import uuid
from glob import glob
from ififuncs import create_csv
from ififuncs import append_csv
from ififuncs import send_gmail
from ififuncs import hashlib_manifest
from ififuncs import diff_textfiles
from ififuncs import make_manifest
from ififuncs import generate_log


'''''
Events:
md5 manifest created of source
framemd5 of source
tiff2dpx
framemd5 output
manifest of output
'''

def set_environment(logfile):
    env_dict = os.environ.copy()
    # https://github.com/imdn/scripts/blob/0dd89a002d38d1ff6c938d6f70764e6dd8815fdd/ffmpy.py#L272
    env_dict['FFREPORT'] = 'file={}:level=48'.format(logfile)
    return env_dict

def make_framemd5(directory, container, log_filename_alteration):
    os.chdir(directory)

    images = glob('*.%s' % container)
    batch_dir = os.path.basename(os.path.dirname(os.path.dirname(root_dir)))
    output_parent_directory = os.path.join(args.o, batch_dir)
    if not os.path.isdir(output_parent_directory):
        os.makedirs(output_parent_directory)

    numberless_filename = images[0].split("_")[0:-1]
    ffmpeg_friendly_name = ''
    counter = 0
    while  counter <len(numberless_filename) :
        ffmpeg_friendly_name += numberless_filename[counter] + '_'
        counter += 1
    output_dirname = output_parent_directory + '/' + ffmpeg_friendly_name + 'dpx_transcodes'
    try:
        os.makedirs(output_dirname + '/image')
        os.makedirs(output_dirname + '/image/logs')
        os.makedirs(output_dirname + '/image/md5')
        os.makedirs(output_dirname + '/image/dpx_files')
        os.makedirs(output_dirname + '/image/xml_files')

    except: OSError

    output = output_dirname + '/image/md5/%s%s.framemd5' % (ffmpeg_friendly_name,container)

    logfile = output_dirname + '/image/logs/%s%s.log' % (ffmpeg_friendly_name, log_filename_alteration)

    env_dict = set_environment(logfile)
    image_seq_without_container = ffmpeg_friendly_name
    ffmpeg_friendly_name += "%06d." + '%s' % container

    framemd5 = ['ffmpeg','-report','-f','image2', '-i', ffmpeg_friendly_name,'-f','framemd5',output]
    print framemd5
    subprocess.call(framemd5, env=env_dict)
    info = [output_dirname, output, image_seq_without_container, output_parent_directory]
    return info
def file_check(dir2check):
    os.chdir(dir2check)
    tiff_check = glob('*.tiff')
    dpx_check = glob('*.dpx')
    if len(dpx_check) > 0:
        print 'DPX sequence, not TIFF. Not processing'
        return 'DPX'
    elif len(tiff_check) > 0:
        return 'TIFF'
    else:
        print 'no images found'
        return 'none'
def remove_bad_files(root_dir):
    rm_these = ['.DS_Store', 'Thumbs.db', 'desktop.ini']
    for root, dirs, files in os.walk(root_dir):
        for name in files:
            path = os.path.join(root, name)
            for i in rm_these:
                if name == i:
                    print '***********************' + 'removing: ' + path
                    os.remove(path)

def premis_log(source_parent_dir, source_directory):
    split_list = os.path.basename(os.path.dirname(source_parent_dir)).split('_')
    premisxml, premis_namespace, doc, premis = setup_xml(source_directory)
    items = {"workflow":"scanning","oe":split_list[0], "filmographic":split_list[1], "sourceAccession":split_list[2], "interventions":['placeholder'], "prepList":['placeholder'], "user":user}
    premis = doc.getroot()
    framemd5_uuid                               = str(uuid.uuid4())
    final_sip_manifest_uuid                              = str(uuid.uuid4())
    a = doc.xpath('//ns:agentIdentifierValue',namespaces={'ns': premis_namespace})
    for i in a:
        if i.text == '9430725d-7523-4071-9063-e8a6ac4f84c4':
            linkingEventIdentifier      = create_unit(-1,i.getparent().getparent(),'linkingEventIdentifier')
            linkingEventIdentifierType = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierType')
            linkingEventIdentifierValue = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierValue')
            linkingEventIdentifierValue.text = final_sip_manifest_uuid
            linkingEventIdentifierType.text = 'UUID'
        elif i.text == 'ee83e19e-cdb1-4d83-91fb-7faf7eff738e':
            linkingEventIdentifier      = create_unit(-1,i.getparent().getparent(),'linkingEventIdentifier')
            linkingEventIdentifierType = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierType')
            linkingEventIdentifierValue = create_unit(1,linkingEventIdentifier, 'linkingEventIdentifierValue')
            linkingEventIdentifierValue.text = framemd5_uuid
            linkingEventIdentifierType.text = 'UUID'
    representation_uuid  = doc.findall('//ns:objectIdentifierValue',namespaces={'ns': premis_namespace})[0].text
    #ffmpegAgent                                 = make_agent(premis,[framemd5_uuid ], 'ee83e19e-cdb1-4d83-91fb-7faf7eff738e')
    make_event(premis, 'message digest calculation', 'Checksum manifest for whole package created', [['UUID','9430725d-7523-4071-9063-e8a6ac4f84c4' ]],final_sip_manifest_uuid,[representation_uuid], 'source', 'now')
    make_event(premis, 'message digest calculation', 'Frame level checksums of images', [['UUID','ee83e19e-cdb1-4d83-91fb-7faf7eff738e' ]], framemd5_uuid, [representation_uuid], 'source', 'now' )
    write_premis(doc, premisxml)

parser = argparse.ArgumentParser(description='DPX2TIFF specific workflow for IFI'
                                ' Written by Kieran O\'Leary.')
parser.add_argument(
                    'input', nargs='+',
                    help='full path of input directory'
                    )
parser.add_argument(
                    '-o',
                    help='full path of output directory', required=True)
args = parser.parse_args()
print args

csv_report_filename = os.path.expanduser("~/Desktop/") + 'dpx_transcode_report' + time.strftime("_%Y_%m_%dT%H_%M_%S") + '.csv'

#permission for correct directories sought from user
permission = ''
all_files = args.input
if not permission == 'y' or permission == 'Y':
    print '\n\n**** All TIFF sequences within these directories will be converted to DPX.\n'
    for i in all_files:
        print i
    permission =  raw_input('\n**** These are the directories that wil be turned into DPX. \n**** If this looks ok, please press Y, otherwise, type N\n' )
    while permission not in ('Y','y','N','n'):
        permission =  raw_input('\n**** These are the directories that wil be turned into DPX. \n**** If this looks ok, please press Y, otherwise, type N\n')
    if permission == 'n' or permission == 'N':
        print 'Exiting at your command- Cheerio for now'
        sys.exit()
    elif permission =='y' or permission == 'Y':
        print 'Ok so!'
        
#user identity sought for accurate premis documentation
user = ''
if not user == '1' or user == '2'or user == '3':
    user =  raw_input('\n\n**** Who are you?\nPress 1 or 2 or 3\n\n1. Brian Cash\n2. Gavin Martin\n3. Raelene Casey\n' )
    while user not in ('1','2','3'):
        user =  raw_input('\n\n**** Who are you?\nPress 1 or 2 or 3\n\n1. Brian Cash\n2. Gavin Martin\n3. Raelene Casey\n')
if user == '1':
    user = 'Brian Cash'
    print 'Hi Brian, Congratulations on becoming a father!!!'
elif user == '2':
    user = 'Gavin Martin'
    print 'Hi Gavin, Have you renewed your subscription to American Cinematographer?'
elif user == '3':
    user = 'Raelene Casey'
    print 'Hi Raelene, Brian must be out of the office'
    time.sleep(1)

create_csv(csv_report_filename, ('Sequence Name', 'Lossless?', 'Start time', 'Finish Time'))
space_counter = 0
for source_directory in all_files:
    for root,dirnames,filenames in os.walk(source_directory):
        for folders in dirnames:
            if ' ' in folders:
                print 'Space found in %s - DELETE IT PLEASE' % os.path.join(root,folders)
                space_counter += 1
    if space_counter > 0:
        sys.exit()

    for root,dirnames,filenames in os.walk(source_directory):
            source_directory = root
            if not file_check(source_directory) == 'TIFF':
                append_csv(csv_report_filename, (source_directory,'EMPTY DIRECTORY - SKIPPED', 'n/a', 'n/a'))
                continue

            root_dir = os.path.dirname(os.path.dirname(root))
            general_log = root_dir + '/logs/image/%s__second_pass_image_log.log' % os.path.basename(root_dir)
            generate_log(general_log, 'Input = %s' % root)
            source_parent_dir           = os.path.dirname(source_directory)
            normpath                    = os.path.normpath(source_directory)
            relative_path               = normpath.split(os.sep)[-1]
            split_path                  = os.path.split(os.path.basename(source_directory))[1]
            start                       = datetime.datetime.now()
            source_manifest             = root_dir + '/%s_manifest.md5' % relative_path
            info                        = make_framemd5(source_directory, 'tiff', 'tiff_framemd5')
            output_dirname              = info[0]
            source_textfile             = info[1]
            fmd5copy                    = root_dir + '/metadata/image'
            shutil.copy(source_textfile,fmd5copy )
            image_seq_without_container = info[2]
            output_parent_directory     = info[3]
            tiff_filename               = image_seq_without_container + "%06d.tiff"
            dpx_filename                = image_seq_without_container + "%06d.dpx"
            logfile                     = output_dirname + '/image/logs/%sdpx_transcode.log' % image_seq_without_container
            env_dict                    = set_environment(logfile)
            generate_log(general_log, 'Starting TIFF to DPX transcode')
            tiff2dpx                    = ['ffmpegnometadata','-report','-f','image2','-framerate','24', '-i', tiff_filename ,output_dirname +  '/image/dpx_files' '/' + dpx_filename]
            print tiff2dpx
            subprocess.call(tiff2dpx,env=env_dict)
            generate_log(general_log, 'TIFF to DPX transcode complete')
            parent_basename =  os.path.basename(output_dirname)
            manifest_textfile = os.path.dirname(output_dirname) + '/' +  parent_basename + '_manifest.md5'
            generate_log(general_log, 'Generating destination manifest via md5deep and storing as  %s' % manifest_textfile)
            other = make_framemd5(output_dirname + '/image/dpx_files', 'dpx', 'dpx_framemd5')
            other_textfile = other[1]
            judgement = diff_textfiles(source_textfile, other_textfile)
            generate_log(general_log, 'Outcome of transcode was:  %s' % judgement)
            make_manifest(output_parent_directory, os.path.basename(output_dirname), manifest_textfile)
            source_metadata_dir = root_dir + '/metadata/image'
            shutil.copy(source_textfile, source_metadata_dir + '/%s' % os.path.basename(source_textfile))
            finish = datetime.datetime.now()
            append_csv(csv_report_filename, (parent_basename,judgement, start, finish))



#! /usr/bin/env python3
'''
Runs (Spectrum) accessioning procedures on packages
that have been through the Object Entry process
Written by Kieran O'Leary
MIT License
'''

import sys
import os
import argparse
import time
import collections
import csv
import ififuncs
import manifest
import makedfxml
import validate
import makepbcore


def make_register():
    '''
    This sends a placeholder accessions register to the desktop logs directory.
    This should get rid of some of the more painful, repetitive identifier matching.
    '''
    desktop_logs_dir = ififuncs.make_desktop_logs_dir()
    register = os.path.join(
        desktop_logs_dir,
        'register_' + time.strftime("%Y-%m-%dT%H_%M_%S.csv")
    )
    ififuncs.create_csv(register, (
        'entry number',
        'accession number',
        'date acquired',
        'date accessioned',
        'acquired from',
        'acquisition method',
        'simple name; basic description; identification; historical information',
        'notes'
    ))
    return register


def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Accessions objects into the Irish Film Institute collection'
        'Completes the transformation of a SIP into an AIP.'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        'input', help='Input directory'
    )
    parser.add_argument(
        '-user',
        help='Declare who you are. If this is not set, you will be prompted.')
    parser.add_argument(
        '-number',
        help='Enter the Accession number for the representation.The parent Object Entry number will be replaced with this name.'
    )
    parser.add_argument(
        '-force',
        help='Renames OE with accession number without confirmation.', action='store_true'
    )
    parser.add_argument(
        '-pbcore',
        help='launches makepbcore and updates AIP', action='store_true'
    )
    parser.add_argument(
        '-reference',
        help='Enter the Filmographic reference number for the representation. This is only relevant when used with -pbcore. For multiple works that are represented, seperate each reference number with a + sign eg AF1234+AC456'
    )
    parser.add_argument(
        '-register',
        help='Path of accessions register CSV file. Mostly to be used by batchaccession.py'
    )
    parser.add_argument(
        '-filmo_csv',
        help='Enter the path to the Filmographic CSV so that the metadata will be stored within the package.'
    )
    parser.add_argument(
        '-parent',
        help='Enter the accession number of the parent object (useful for reproductions)'
    )
    parser.add_argument(
        '-acquisition_type',
        help='Enter the Type of Acquisition in the form of a number referring to the IFI controlled vocabulary.'
    )
    parser.add_argument(
        '-donor',
        help='Enter a string that represents the source of acquisition'
    )
    parser.add_argument(
        '-depositor_reference',
        help='Enter a number that represents the identifier for the source of acquisition'
    )
    parser.add_argument(
        '-donation_date',
        help='Enter the date of dontation/acquisition/deposit etc. 2018-12-30 or 30/12/2018 depending on source of data'
    )
    parser.add_argument(
        '-reproduction_creator',
        help='Enter the person/organisation that created the reproduction. Only suitable for reprodctions, not donations!'
    )
    parsed_args = parser.parse_args(args_)
    return parsed_args


def make_dfxml(args,new_uuid_path,uuid):
    '''
    Adds Digital Forensics XML to metadata folder and updates manifests.
    '''
    metadata = os.path.join(new_uuid_path, 'metadata')
    dfxml = os.path.join(metadata, uuid + '_dfxml.xml')
    makedfxml.main([new_uuid_path, '-n', '-o', dfxml])
    return dfxml

def insert_filmographic(filmographic_csv, Reference_Number, package_filmographic):
    '''
    Should this be done at the accession.py level?
    yes, as it extracts the title.
    And it should be done after the args.pbcore bit as
    that is what extracts the reference number.
    filmographic_csv=source filmographic csv with reference numbers
    Reference_Number=the specific reference number that you would like to extract
    package_filmographic = the full path of the filmographic to be instered in /metadata
    '''
    csv_dict = ififuncs.extract_metadata(filmographic_csv)
    for items in csv_dict:
        for x in items:
            if type(x) in [collections.OrderedDict, dict]:
                if Reference_Number in x['Filmographic URN'].upper():
                    with open(package_filmographic, 'w', encoding='utf-8') as csvfile:
                        fieldnames = csv_dict[1]
                        writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
                        writer.writeheader()
                        writer.writerow(x)
def main(args_):
    '''
    Launches the various functions that will accession a package
    '''
    args = parse_args(args_)
    source = args.input
    uuid_directory = ififuncs.check_for_sip([source])
    if uuid_directory is not None:
        oe_path = os.path.dirname(uuid_directory)
        oe_number = os.path.basename(oe_path)
        if args.user:
            user = args.user
        else:
            user = ififuncs.get_user()
        if args.number:
            if args.number[:3] != 'aaa':
                print('First three characters must be \'aaa\' and last four characters must be four digits')
                accession_number = ififuncs.get_accession_number()
            elif len(args.number[3:]) != 4:
                accession_number = ififuncs.get_accession_number()
                print('First three characters must be \'aaa\' and last four characters must be four digits')
            elif not args.number[3:].isdigit():
                accession_number = ififuncs.get_accession_number()
                print('First three characters must be \'aaa\' and last four characters must be four digits')
            else:
                accession_number = args.number
        else:
            accession_number = ififuncs.get_accession_number()
        if args.reference:
            Reference_Number = args.reference.upper()
        else:
            Reference_Number = ififuncs.get_reference_number()
        if args.acquisition_type:        
            acquisition_type = ififuncs.get_acquisition_type(args.acquisition_type)
            print(acquisition_type)
        accession_path = os.path.join(
            os.path.dirname(oe_path), accession_number
        )
        uuid = os.path.basename(uuid_directory)
        new_uuid_path = os.path.join(accession_path, uuid)
        logs_dir = os.path.join(new_uuid_path, 'logs')
        sipcreator_log = os.path.join(logs_dir, uuid) + '_sip_log.log'
        if args.force:
            proceed = 'Y'
        else:
            proceed = ififuncs.ask_yes_no(
                'Do you want to rename %s with %s' % (oe_number, accession_number)
            )
        if proceed == 'Y':
            os.rename(oe_path, accession_path)
        if args.register:
            register = args.register
        else:
            register = make_register()
        ififuncs.append_csv(register, (oe_number.upper()[:2] + '-' + oe_number[2:], accession_number, '','','','','', ''))
        ififuncs.generate_log(
            sipcreator_log,
            'EVENT = accession.py started'
        )
        ififuncs.generate_log(
            sipcreator_log,
            'eventDetail=accession.py %s' % ififuncs.get_script_version('accession.py')
        )
        ififuncs.generate_log(
            sipcreator_log,
            'Command line arguments: %s' % args
        )
        ififuncs.generate_log(
            sipcreator_log,
            'EVENT = agentName=%s' % user
        )
        ififuncs.generate_log(
            sipcreator_log,
            'EVENT = eventType=Identifier assignment,'
            ' eventIdentifierType=accession number, value=%s'
            % accession_number
        )
        ififuncs.generate_log(
            sipcreator_log,
            'EVENT = eventType=accession,'
            ' eventIdentifierType=accession number, value=%s'
            % accession_number
        )
        sip_manifest = os.path.join(
            accession_path, uuid
            ) + '_manifest.md5'
        sha512_log = manifest.main([new_uuid_path, '-sha512', '-s'])
        sha512_manifest = os.path.join(
            os.path.dirname(new_uuid_path), uuid + '_manifest-sha512.txt'
        )
        ififuncs.merge_logs_append(sha512_log, sipcreator_log, sip_manifest)
        os.remove(sha512_log)
        print('Generating Digital Forensics XML')
        dfxml_check = True
        try:
            dfxml = make_dfxml(args, new_uuid_path, uuid)
            ififuncs.generate_log(
                sipcreator_log,
                'EVENT = Metadata extraction - eventDetail=File system metadata extraction using Digital Forensics XML, eventOutcome=%s, agentName=makedfxml' % (dfxml)
            )
        except UnicodeDecodeError:
            ififuncs.generate_log(
                sipcreator_log,
                'EVENT = Metadata extraction - eventDetail=File system metadata extraction using Digital Forensics XML, eventOutcome=FAILURE due to UnicodeDecodeError, agentName=makedfxml'
            )
            dfxml_check = False
        # this is inefficient. The script should not have to ask for reference
        # number twice if someone wants to insert the filmographic but do not
        # want to make the pbcore csv, perhaps because the latter already exists.
        if args.filmo_csv:
            metadata_dir = os.path.join(new_uuid_path, 'metadata')
            if '+' in Reference_Number:
                reference_list = Reference_Number.split('+')
            else:
                reference_list = [Reference_Number]
            for ref in reference_list:
                package_filmographic = os.path.join(metadata_dir, ref + '_filmographic.csv')
                insert_filmographic(args.filmo_csv, ref , package_filmographic)
                ififuncs.generate_log(
                    sipcreator_log,
                    'EVENT = Metadata extraction - eventDetail=Filmographic descriptive metadata added to metadata folder, eventOutcome=%s, agentName=accession.py' % (package_filmographic)
                )
                ififuncs.manifest_update(sip_manifest, package_filmographic)
                ififuncs.sha512_update(sha512_manifest, package_filmographic)
                print('Filmographic descriptive metadata added to metadata folder')
        ififuncs.generate_log(
            sipcreator_log,
            'EVENT = accession.py finished'
        )
        ififuncs.checksum_replace(sip_manifest, sipcreator_log, 'md5')
        ififuncs.checksum_replace(sha512_manifest, sipcreator_log, 'sha512')
        if dfxml_check is True:
            ififuncs.manifest_update(sip_manifest, dfxml)
            ififuncs.sha512_update(sha512_manifest, dfxml)
        if args.pbcore:
            for ref in reference_list:
                makepbcore_cmd = [accession_path, '-p', '-user', user, '-reference', ref]
                if args.parent:
                    makepbcore_cmd.extend(['-parent', args.parent])
                if args.acquisition_type:
                    makepbcore_cmd.extend(['-acquisition_type', args.acquisition_type])
                if args.donor:
                    makepbcore_cmd.extend(['-donor', args.donor])
                if args.donor:
                    makepbcore_cmd.extend(['-depositor_reference', args.depositor_reference])
                if args.reproduction_creator:
                    makepbcore_cmd.extend(['-reproduction_creator', args.reproduction_creator])
                if args.donation_date:
                    makepbcore_cmd.extend(['-donation_date', args.donation_date])
                makepbcore.main(makepbcore_cmd)
    else:
        print('not a valid package. The input should include a package that has been through Object Entry')

if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python3
'''
Creates framemd5 sidecars on all mov/mkv files in all subfolders beneath your input.
If the input is a file, then framemd5.py will just generate a sidecar for this one file.
'''
import subprocess
import os
import argparse
import ififuncs

def parse_args():
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Creates framemd5 sidecars on all mov/mkv files in all subfolders beneath your input.'
        ' If the input is a file, then framemd5.py will just generate a sidecar for this one file.'
    )
    parser.add_argument(
        '-i',
        help='full path of input file or directory', required=True
    )
    parsed_args = parser.parse_args()
    return parsed_args

def main():
    '''
    Simple recursive process that makes framemd5 sidecar reports.
    '''
    ififuncs.check_existence(['ffmpeg'])
    args = parse_args()
    source = args.i
    fmd5 = source + '_source.framemd5'
    if os.path.isfile(source):
        cmd = [
            'ffmpeg',
            '-i',
            source,
            '-f',
            'framemd5',
            '-an',
            fmd5
            ]
        subprocess.call(cmd)
    else:
        for root, _, filenames in os.walk(source):
            for filename in filenames:
                if filename.endswith(('.mov', '.mkv', '.dv')):
                    if filename[0] != '.':
                        full_path = os.path.join(root, filename)
                        cmd = [
                            'ffmpeg',
                            '-i',
                            full_path,
                            '-f',
                            'framemd5',
                            '-an',
                            full_path + '_source.framemd5'
                            ]
                        subprocess.call(cmd)


if __name__ == '__main__':
    main()




import sys
import os

def main():
    
    input = sys.argv[1]
    print('Label Frontend,Label Backend,Definition,Format of content,Obligation,Repeatability')
    with open(input, 'r') as source:
        raw_dump = source.read()
        raw_dump = raw_dump.replace('\r', '\n')
        raw_info =  raw_dump.split('\n')
    #print raw_info
    for line in raw_info:
        if line != '':
            mandatory = 'optional'
            repeatability = 'repeatable'
            format_of_content = line.split(':')[1].split(',')[0][1:]
            if 'Text(subst-list)' in line:
                format_of_content = 'Text(subst-list)' 
            backend_name = line.split(':')[0].replace(':', '').split('.')[1][1:]
            if 'required' in line:
                mandatory = 'required'
            if ', Term & Word,' in line:
                indexing = 'Term & Word Indexing'
            elif ', Word' in line:
                indexing = 'Word Indexing'
            elif ', Term' in line:
                indexing = 'Term Indexing'
            if 'single-only' in line:
                repeatability = 'not-repeatable'
            if 'valid-list' in line:
                format_of_content += ':Validation list'
            if 'override' in line:
                format_of_content += ':override'
            if 'update-valid-list' in line:
                format_of_content += ':update-valid-list'
            a =  "'','%s','', '%s:%s','%s','%s'"  % (backend_name, format_of_content, indexing,  mandatory, repeatability)
            print(a.replace('\'', ''))
if __name__ == '__main__':
    main()



#!/usr/bin/env python3
'''
Validates md5 or sha512 sidecar checksum manifests.
'''
import sys
import os
import argparse
import time
import unicodedata
import ififuncs
from ififuncs import make_desktop_logs_dir


def get_input(manifest):
    '''
    Figures out what kind of input is passed to the script.
    '''
    if not manifest.endswith(('.txt', '.md5', '.exf')):
        print('Usage: validate.py manifest \nManifests can be a .txt or a .md5 or an ExactFile .exf file.')
        sys.exit()
    elif manifest.endswith('.exf'):
        print('ExactFile manifests have 5 lines of extra info which will confuse validate.py until I get around to fixing this. It will list some missing files but will validate checksums as usual.')
        return manifest
    else:
        return manifest

def parse_manifest(manifest, log_name_source, args):
    '''
    Analyses the manifest to see if any files are missing.
    Returns a list of missing files and a dictionary containing checksums
    and paths.
    '''
    if manifest.endswith('md5'):
        source_dir = os.path.join(
            os.path.dirname(manifest), os.path.basename(manifest).replace('_manifest.md5','')
        )
    elif manifest.endswith('sha512.txt'):
        source_dir = os.path.join(
            os.path.dirname(manifest), os.path.basename(manifest).replace('_manifest-sha512.txt','')
        )
    source_count, file_list = ififuncs.count_stuff(source_dir)
    missing_files_list = []
    manifest_dict = {}
    paths = []
    proceed = 'Y'
    os.chdir(os.path.dirname(manifest))
    with open(manifest, 'r', encoding='utf-8') as manifest_object:
        try:
            manifest_list = manifest_object.readlines()
        except UnicodeDecodeError:
            with open(manifest, 'r', encoding='cp1252') as manifest_object:
                manifest_list = manifest_object.readlines()
        for entries in manifest_list:
            checksum = entries.split(' ')[0]
            if 'manifest-sha512.txt' in manifest:
                path = entries[130:].replace('\r', '').replace('\n', '')
            else:
                path = entries[34:].replace('\r', '').replace('\n', '')
            path = unicodedata.normalize('NFC', path).replace('\\', '/')
            if not os.path.isfile(path):
                path = unicodedata.normalize('NFD', path)
            if not os.path.isfile(path):
                ififuncs.generate_log(
                    log_name_source,
                    '%s is missing' % path
                )
                print(('%s is missing' % path))
                missing_files_list.append(path)
            elif os.path.isfile(path):
                manifest_dict[path] = checksum
                paths.append(path)
    manifest_file_count = len(manifest_list)
    if source_count != manifest_file_count:
        print(' - There is mismatch between your file count and the manifest file count')
        print(' - checking which files are different')
        for i in file_list:
            if i not in paths:
                print((i, 'is present in your source directory but not in the source manifest'))
        if not args.y:
            proceed = ififuncs.ask_yes_no('Do you want to proceed regardless?')
    if proceed == 'N':
        print('Exiting')
        sys.exit()
    else:
        if len(missing_files_list) > 0:
            print(('The number of missing files: %s' % len(missing_files_list)))
            ififuncs.generate_log(
                log_name_source,
                'The number of missing files is: %s' % len(missing_files_list)
            )
        elif len(missing_files_list) == 0:
            print('All files present')
            ififuncs.generate_log(
                log_name_source,
                'All files present'
            )
    return manifest_dict, missing_files_list

def validate(manifest_dict, manifest, log_name_source, missing_files_list):
    '''
    Validates the files listed in the checksum manifest.
    '''
    ififuncs.generate_log(
        log_name_source,
        'Validating %s ' % manifest
    )
    error_counter = 0
    manifest_directory = os.path.dirname(manifest)
    os.chdir(manifest_directory)
    error_list = []
    for i in sorted(manifest_dict.keys()):
        print(('Validating %s' % i))
        if 'manifest-sha512.txt' in manifest:
            current_hash = ififuncs.hashlib_sha512(i)
        else:
            current_hash = ififuncs.hashlib_md5(i)
        if current_hash == manifest_dict[i]:
            print(('%s has validated' % i))
        else:
            print(('%s has mismatched checksum - %s expected - %s hashed' % (i, manifest_dict[i], current_hash)))
            ififuncs.generate_log(
                log_name_source,
                '%s has mismatched checksum - %s expected - %s hashed' % (i, manifest_dict[i], current_hash)
            )
            error_list.append('%s has mismatched checksum - %s expected - %s hashed' % (i, manifest_dict[i], current_hash))
            error_counter += 1
    if error_counter > 0:
        print(('\n\n*****ERRORS***********!!!!\n***********\nThe number of mismatched checksums is: %s\n***********\n' % error_counter))
        ififuncs.generate_log(
            log_name_source,
            'The number of mismatched checksums is: %s' % error_counter
        )
        print('***** List of mismatched files*****')
        for i in error_list:
            print(i)
    elif len(missing_files_list) == 0:
        print('All checksums have validated')
        ififuncs.generate_log(
            log_name_source,
            'All checksums have validated'
        )
    if len(missing_files_list) > 0:
        print(('ERRORS - The number of missing files: %s' % len(missing_files_list)))
        ififuncs.generate_log(
            log_name_source,
            'ERRORS - The number of mismatched checksums is: %s' % len(missing_files_list)
        )
        for i in missing_files_list:
            print((('%s is missing') % i))
    return error_counter + len(missing_files_list)


def make_parser(args_):
    '''
    Creates command line arguments and help.
    '''
    parser = argparse.ArgumentParser(description='MD5 checksum manifest validator. Currently this script expects an md5 checksum, followed by two spaces, followed by a file path.'
                                     ' Written by Kieran O\'Leary.')
    parser.add_argument('input', help='file path of md5 checksum file')
    parser.add_argument('-update_log', help='updates the package log file with the fixity check information', action='store_true')
    parser.add_argument('-y', help='answer Y to user input questions regarding manifest issues', action='store_true')
    parsed_args = parser.parse_args(args_)
    return parsed_args


def check_manifest(args, log_name_source):
    '''
    Launches other functions.
    '''
    manifest = get_input(args.input)
    manifest_dict, missing_files_list = parse_manifest(manifest, log_name_source, args)
    error_counter = validate(manifest_dict, manifest, log_name_source, missing_files_list)
    return manifest, error_counter


def log_results(manifest, log, args):
    '''
    If a sipcreator type log is found,validate will update the log with the
    results.
    '''
    updated_manifest = []
    if 'manifest-sha512.txt' in manifest:
        basename = os.path.basename(manifest).replace('_manifest-sha512.txt', '')
    else:
        basename = os.path.basename(manifest).replace('_manifest.md5', '')
    possible_manifests = [basename + '_manifest-sha512.txt', basename + '_manifest.md5']
    logname = basename + '_sip_log.log'
    sip_dir = os.path.join(
        os.path.dirname(args.input), basename)
    logs_dir = os.path.join(sip_dir, 'logs')
    logfile = os.path.join(logs_dir, logname)
    if os.path.isfile(logfile):
        with open(log, 'r') as fo:
            validate_log = fo.readlines()
        with open(logfile, 'a') as ba:
            for lines in validate_log:
                ba.write(lines)
        for possible_manifest in possible_manifests:
            if os.path.isfile(possible_manifest):
                with open(possible_manifest, 'r') as manifesto:
                    manifest_lines = manifesto.readlines()
                    for lines in manifest_lines:
                        if logname in lines:
                            if 'manifest-sha512.txt' in possible_manifest:
                                lines = lines[:127].replace(lines[:127], ififuncs.hashlib_sha512(logfile)) + lines[128:]
                            elif '_manifest.md5' in possible_manifest:
                                lines = lines[:31].replace(lines[:31], ififuncs.hashlib_md5(logfile)) + lines[32:]
                        updated_manifest.append(lines)
                with open(possible_manifest, 'w') as fo:
                    for lines in updated_manifest:
                        fo.write(lines)
                updated_manifest = []


def main(args_):
    '''
    Launches all other functions when called from the command line.
    '''
    args = make_parser(args_)
    desktop_logs_dir = make_desktop_logs_dir()
    log_name_source_ = os.path.basename(args.input) + time.strftime("_%Y_%m_%dT%H_%M_%S")
    log_name_source = "%s/%s_fixity_validation.log" % (desktop_logs_dir, log_name_source_)
    ififuncs.generate_log(
        log_name_source,
        'EVENT = validate.py started'
    )
    ififuncs.generate_log(
        log_name_source,
        'eventDetail=validate.py %s' % ififuncs.get_script_version('validate.py')
    )
    ififuncs.generate_log(
        log_name_source,
        'Command line arguments: %s' % args
    )
    manifest, error_counter = check_manifest(args, log_name_source)
    if args.update_log:
        log_results(manifest, log_name_source, args)
    return error_counter

if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python
'''
Deletes files after sipcreator has been run, but before accession.py has been run.
Manifests are updated and metadata is deleted.
'''
import os
import argparse
import sys
import datetime
import ififuncs


def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Deletes files from Object Entry packages'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        '-i', nargs='+',
        help='full path of files to be deleted', required=True
    )
    parser.add_argument(
        '-uuid_path',
        help='full path of \'sipcreator\' Object Entry package'
    )
    parser.add_argument(
        '-user',
        help='Declare who you are. If this is not set, you will be prompted.')
    parsed_args = parser.parse_args(args_)
    return parsed_args


def remove_from_manifest(manifest, old_oe, new_log_textfile):
    '''
    Removes a file from a manifest and logs the result in the logfile.
    '''
    updated_lines = []
    with open(manifest, 'r') as file_object:
        checksums = file_object.readlines()
        for line in checksums:
            if old_oe in line:
                print(('%s has been removed from the package manifest' % line))
                ififuncs.generate_log(
                    new_log_textfile,
                    'EVENT = eventType=metadata modification,'
                    ' agentName=deletefiles.py,'
                    ' eventDetail=%s has been removed from the package manifest' % line)
                continue
            else:
                updated_lines.append(line)
    with open(manifest, 'w') as updated_manifest:
        for updated_line in updated_lines:
            updated_manifest.write(updated_line)


def main(args_):
    '''
    Launch all the functions for creating an IFI SIP.
    '''
    args = parse_args(args_)
    source = args.uuid_path
    sip_path = ififuncs.check_for_sip([source])
    if sip_path is not None:
        oe_path = os.path.dirname(sip_path)
        uuid = os.path.basename(sip_path)
        sip_manifest = os.path.join(
            oe_path, uuid
            ) + '_manifest.md5'
    else:
        # this is assuming that the other workflow will be the
        # special collections workflow that has the uuid as the parent.
        # some real checks should exist for this whole if/else flow.
        sip_path = args.uuid_path
        oe_path = os.path.dirname(args.uuid_path)
        uuid = os.path.basename(sip_path)
        sip_manifest = os.path.join(
            oe_path, uuid + '_manifest.md5'
            )
    start = datetime.datetime.now()
    print(args)
    if args.user:
        user = args.user
    else:
        user = ififuncs.get_user()
    new_log_textfile = os.path.join(sip_path, 'logs' + '/' + uuid + '_sip_log.log')
    ififuncs.generate_log(
        new_log_textfile,
        'EVENT = deletefiles.py started'
    )
    ififuncs.generate_log(
        new_log_textfile,
        'eventDetail=deletefiles.py %s' % ififuncs.get_script_version('deletefiles.py')
    )
    ififuncs.generate_log(
        new_log_textfile,
        'Command line arguments: %s' % args
    )
    ififuncs.generate_log(
        new_log_textfile,
        'EVENT = agentName=%s' % user
    )
    metadata_dir = os.path.join(sip_path, 'metadata')
    for filename in args.i:
        # add test to see if it actually deleted - what if read only?
        os.remove(filename)
        print(('%s has been deleted' % filename))
        ififuncs.generate_log(
            new_log_textfile,
            'EVENT = eventType=deletion,'
            ' eventOutcomeDetailNote=%s has been deleted,'
            ' agentName=os.remove()'
            % filename
        )
        for metadata in os.listdir(metadata_dir):
            if os.path.basename(filename) in metadata:
                os.remove(os.path.join(metadata_dir, metadata))
                print(('%s has been deleted' %  os.path.join(metadata_dir, metadata)))
                ififuncs.generate_log(
                    new_log_textfile,
                    'EVENT = eventType=deletion,'
                    ' eventOutcomeDetailNote=%s has been deleted,'
                    ' agentName=os.remove()'
                    % os.path.join(metadata_dir, metadata)
                )
        remove_from_manifest(sip_manifest, os.path.basename(filename), new_log_textfile)
        ififuncs.sort_manifest(sip_manifest)
    ififuncs.generate_log(
        new_log_textfile,
        'EVENT = deletefiles.py finished'
    )    
    ififuncs.checksum_replace(sip_manifest, new_log_textfile, 'md5')
    finish = datetime.datetime.now()
    print('\n- %s ran this script at %s and it finished at %s' % (user, start, finish))


if __name__ == '__main__':
    main(sys.argv[1:])



#!/usr/bin/env python
import sys
import os
import subprocess
import makeffv1
import dvsip
from ififuncs import get_mediainfo

def main():
    video_files, csv_report_filename = makeffv1.get_input()
    dv_files = dvsip.get_input()
    all_files = video_files + dv_files
    if os.path.isdir(sys.argv[1]):
       output = sys.argv[1]
    elif os.path.isfile(sys.argv[1]):
       output = os.path.dirname(sys.argv[1])
    proxies_dir = os.path.join(output, 'proxies')
    if not os.path.isdir(proxies_dir):
        os.makedirs(proxies_dir)
    for video in all_files:
        subprocess.check_call(
            [sys.executable, os.path.expanduser("~/ifigit/ifiscripts/bitc.py"),
            '-clean','-yadif',
            '-crf','20',
            os.path.join(output,video),
            '-o', proxies_dir]
            )
    makeffv1.make_ffv1(video_files, csv_report_filename)
    dvsip.make_sip(dv_files)
    print 'Proxies sent to %s' % proxies_dir


if __name__ == '__main__':
    main()



#!/usr/bin/env python
'''
Make a sha512 manifest
'''
import os
import subprocess
import sys


def main():
    '''
    Super basic sha512 manifest generator.
    Haven't looked at this in ages, needs a lot more work!
    '''
    source = sys.argv[1]
    total_file_count = 0
    print 'Determining number of files to be processed'
    for root, _, filenames in os.walk(source):
        for files in filenames:
            total_file_count += 1
    progress_counter = 1
    manifest = os.path.dirname(source) + '/manifest_sha512.txt'
    for root, _, filenames in os.walk(source):
        for files in filenames:
            print 'processing %s - %d of %d' % (
                files, progress_counter, total_file_count
                )
            sha512 = subprocess.check_output(
                ['openssl', 'sha512', '-r', os.path.join(root, files)]
                )
            root2 = root.replace(os.path.dirname(source), '')
            with open(manifest, "ab") as manifest_object:
                manifest_object.write(
                    sha512[:128] + ' ' + os.path.join(
                        root2, files
                        ).replace("\\", "/") + '\n'
                    )
            progress_counter += 1
    print 'Manifest created in %s' % manifest


if __name__ == '__main__':
    main()



#!/usr/bin/env python3
'''
Performs normalisation to FFV1/Matroska.
This performs a basic normalisation and does not enforce any folder structure.
This supercedes makeffv1 within our workflows. This is mostly because makeffv1 imposes a specific, outdated
folder structure, and it's best to let SIPCREATOR handle the folder structure and let normalise.py handle
the actual normalisation.
'''
import sys
import os
import subprocess
import argparse
import shutil
import time
import ififuncs
import sipcreator

def parse_args(args_):
    '''
    Parse command line arguments.
    '''
    parser = argparse.ArgumentParser(
        description='Performs normalisation to FFV1/Matroska.'
        ' Written by Kieran O\'Leary.'
    )
    parser.add_argument(
        '-i',
        help='full path of input file or directory', required=True
    )
    parser.add_argument(
        '-o', '-output',
        help='full path of output directory', required=True
    )
    parser.add_argument(
        '-sip',
        help='Run sipcreator.py on the resulting file.', action='store_true'
    )
    parser.add_argument(
        '-user',
        help='Declare who you are. If this is not set, you will be prompted.')
    parser.add_argument(
        '-oe',
        help='Enter the Object Entry number for the representation.SIP will be placed in a folder with this name.'
    )
    parser.add_argument(
        '-supplement', nargs='+',
        help='Enter the full path of files or folders that are to be added to the supplemental subfolder within the metadata folder. Use this for information that supplements your preservation objects but is not to be included in the objects folder.'
    )
    parsed_args = parser.parse_args(args_)
    return parsed_args


def normalise_process(filename, output_folder):
    '''
    Begins the actual normalisation process using FFmpeg
    '''
    output_uuid = ififuncs.create_uuid()
    print(' - The following UUID has been generated: %s' % output_uuid)
    output = "%s/%s.mkv" % (
        output_folder, output_uuid
        )
    print(' - The normalised file will have this filename: %s' % output)
    fmd5 = "%s/%s_source.framemd5" % (
        output_folder, os.path.basename(filename)
        )
    print(' - Framemd5s for each frame of your input file will be stored in: %s' % fmd5)

    ffv1_logfile = os.path.join(output_folder, '%s_normalise.log' % output_uuid)
    print(' - The FFmpeg logfile for the transcode will be stored in: %s' % ffv1_logfile)
    print(' - FFmpeg will begin normalisation now.')
    ffv1_env_dict = ififuncs.set_environment(ffv1_logfile)
    ffv1_command = [
        'ffmpeg',
        '-i', filename,
        '-c:v', 'ffv1',         # Use FFv1 codec
        '-g', '1',              # Use intra-frame only aka ALL-I aka GOP=1
        '-level', '3',          # Use Version 3 of FFv1
        '-c:a', 'copy',         # Copy and paste audio bitsream with no transcoding
        '-map', '0',
        '-dn',
        '-report',
        '-slicecrc', '1',
        '-slices', '16',
    ]
    if ififuncs.check_for_fcp(filename) is True:
        print(' - A 720/576 file with no Pixel Aspect Ratio and scan type metadata has been detected.')
        ffv1_command += [
            '-vf',
            'setfield=tff, setdar=4/3'
            ]
        print(' - -vf setfield=tff, setdar=4/3 will be added to the FFmpeg command.')
        ffprobe_dict = ififuncs.get_ffprobe_dict(filename)
        # let's stipulate the colour metadata if not present for SD PAL material.
        if not ififuncs.get_colour_metadata(ffprobe_dict):
            ffv1_command += ['-color_primaries', 'bt470bg', '-color_trc', 'bt709', '-colorspace', 'bt470bg' ]
    elif ififuncs.check_for_blackmagic(filename) is True:
        print(' - A 720/576  with TFF scan type, clap atom featuring 702 width and a PAR of 1.093 has been detected.')
        ffv1_command += ['-vf', 'setdar=4/3', '-color_primaries', 'bt470bg', '-color_trc', 'bt709', '-colorspace', 'bt470bg']
    ffv1_command += [
        output,
        '-f', 'framemd5', '-an',  # Create decoded md5 checksums for every frame of the input. -an ignores audio
        fmd5
        ]
    print(ffv1_command)
    subprocess.call(ffv1_command, env=ffv1_env_dict)
    return output, output_uuid, fmd5, ffv1_logfile

def verify_losslessness(output_folder, output, output_uuid, fmd5):
    '''
    Verify the losslessness of the process using framemd5.
    An additional metadata check should also occur.
    '''
    verdict = 'undeclared'
    fmd5_logfile = os.path.join(output_folder, '%s_framemd5.log' % output_uuid)
    fmd5ffv1 = "%s/%s.framemd5" % (output_folder, output_uuid)
    print(' - Framemd5s for each frame of your output file will be stored in: %s' % fmd5ffv1)
    fmd5_env_dict = ififuncs.set_environment(fmd5_logfile)
    print(' - FFmpeg will attempt to verify the losslessness of the normalisation by using Framemd5s.')
    fmd5_command = [
        'ffmpeg',    # Create decoded md5 checksums for every frame
        '-i', output,
        '-report',
        '-f', 'framemd5', '-an',
        fmd5ffv1
        ]
    print(fmd5_command)
    subprocess.call(fmd5_command, env=fmd5_env_dict)
    checksum_mismatches = ififuncs.diff_framemd5s(fmd5, fmd5ffv1)
    if len(checksum_mismatches) == 1:
        if checksum_mismatches[0] == 'sar':
            print('Image is lossless, but the Pixel Aspect Ratio is different than the source - this may have been intended.')
            verdict = 'Image is lossless, but the Pixel Aspect Ratio is different than the source - this may have been intended.'
        else:
            print('not lossless')
            verdict = 'not lossless'
    elif len(checksum_mismatches) > 1:
        print('not lossless')
        verdict = 'not lossless'
    elif len(checksum_mismatches) == 0:
        print('YOUR FILES ARE LOSSLESS YOU SHOULD BE SO HAPPY!!!')
        verdict = 'lossless'
    return fmd5_logfile, fmd5ffv1, verdict

def main(args_):
    ififuncs.check_existence(['ffmpeg', 'mediainfo'])
    print('\n - Normalise.py started')
    args = parse_args(args_)
    print(args)
    source = args.i
    output_folder = args.o
    file_list = sorted(ififuncs.get_video_files(source))
    if args.sip:
        if args.user:
            user = args.user
        else:
            user = ififuncs.get_user()
        if args.oe:
            if args.oe[:2] != 'oe':
                print('First two characters must be \'oe\' and last four characters must be four digits')
                object_entry = ififuncs.get_object_entry()
            elif len(args.oe[2:]) not in range(4, 6):
                print('First two characters must be \'oe\' and last four characters must be four digits')
                object_entry = ififuncs.get_object_entry()
            elif not args.oe[2:].isdigit():
               object_entry = ififuncs.get_object_entry()
               print('First two characters must be \'oe\' and last four characters must be four digits')
            else:
                object_entry = args.oe
        else:
            object_entry = ififuncs.get_object_entry()
    if args.sip:
        oe_digits = int(object_entry.replace('oe', ''))
    for filename in file_list:
        log_name_source = os.path.join(args.o, '%s_normalise_log.log' % time.strftime("_%Y_%m_%dT%H_%M_%S"))
        ififuncs.generate_log(log_name_source, 'normalise.py started.')
        ififuncs.generate_log(
            log_name_source,
            'Command line arguments: %s' % args
        )
        if args.sip:
            ififuncs.generate_log(
                log_name_source,
                'EVENT = agentName=%s' % user
            )
        print('\n - Processing: %s' % filename)
        ififuncs.generate_log(
            log_name_source,
            'EVENT = Normalization, status=started, eventType=Normalization, agentName=ffmpeg, eventDetail=Source object to be normalised=%s' % filename)
        output, output_uuid, fmd5, ffv1_logfile = normalise_process(filename, output_folder)
        ififuncs.generate_log(
            log_name_source,
            'EVENT = Normalization, status=finished, eventType=Normalization, agentName=ffmpeg, eventDetail=Source object normalised into=%s' % output)
        inputxml, inputtracexml, dfxml = ififuncs.generate_mediainfo_xmls(filename, output_folder, output_uuid, log_name_source)
        fmd5_logfile, fmd5ffv1, verdict = verify_losslessness(output_folder, output, output_uuid, fmd5)
        ififuncs.generate_log(
            log_name_source,
            'EVENT = losslessness verification, status=finished, eventType=messageDigestCalculation, agentName=ffmpeg, eventDetail=MD5s of AV streams of output file generated for validation, eventOutcome=%s' % verdict)
        if args.sip:
            object_entry_complete = 'oe' + str(oe_digits)
            supplement_cmd = ['-supplement', inputxml, inputtracexml, dfxml]
            sipcreator_cmd = ['-i', output, '-move', '-u', output_uuid, '-user', user, '-oe', object_entry_complete, '-o', args.o]
            if args.supplement:
                supplement_cmd.extend(args.supplement)
            sipcreator_cmd.extend(supplement_cmd)
            sipcreator_log, sipcreator_manifest = sipcreator.main(sipcreator_cmd)
            metadata_dir  = os.path.join(os.path.dirname(os.path.dirname(sipcreator_log)), 'metadata')
            shutil.move(fmd5, metadata_dir)
            shutil.move(fmd5_logfile, os.path.dirname(sipcreator_log))
            shutil.move(fmd5ffv1, metadata_dir)
            shutil.move(ffv1_logfile.replace('\\\\', '\\').replace('\:', ':'), os.path.dirname(sipcreator_log))
            logs_dir = os.path.dirname(sipcreator_log)
            ififuncs.manifest_update(sipcreator_manifest, os.path.join(metadata_dir, os.path.basename(fmd5)))
            ififuncs.manifest_update(sipcreator_manifest, os.path.join(metadata_dir, os.path.basename(fmd5ffv1)))
            ififuncs.manifest_update(sipcreator_manifest, os.path.join(logs_dir, os.path.basename(ffv1_logfile.replace('\\\\', '\\').replace('\:', ':'))))
            ififuncs.manifest_update(sipcreator_manifest, os.path.join(logs_dir, os.path.basename(fmd5_logfile.replace('\\\\', '\\').replace('\:', ':'))))
            ififuncs.merge_logs(log_name_source, sipcreator_log, sipcreator_manifest)
            os.remove(dfxml)
            os.remove(inputxml)
            os.remove(inputtracexml)
            print('The judgement above only refers to the copyit job, the losslessness judgement is: %s' % verdict)
            oe_digits += 1

if __name__ == '__main__':
    main(sys.argv[1:])
